@@ -17,6 +17,7 @@
 #include <array>
 #include <string>
 #include "sdf/AirPressure.hh"
+#include "sdf/parser.hh"
 
 using namespace sdf;
 
@@ -35,7 +36,7 @@ class sdf::AirPressure::Implementation
 
 //////////////////////////////////////////////////
 AirPressure::AirPressure()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -86,7 +87,7 @@ bool AirPressure::operator!=(const AirPressure &_air) const
 bool AirPressure::operator==(const AirPressure &_air) const
 {
   return this->dataPtr->noise == _air.dataPtr->noise &&
-         ignition::math::equal(this->dataPtr->referenceAltitude,
+         gz::math::equal(this->dataPtr->referenceAltitude,
                                _air.dataPtr->referenceAltitude);
 }
 
@@ -113,3 +114,18 @@ void AirPressure::SetPressureNoise(const Noise &_noise)
 {
   this->dataPtr->noise = _noise;
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr AirPressure::ToElement() const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("air_pressure.sdf", elem);
+
+  elem->GetElement("reference_altitude")->Set<double>(
+      this->ReferenceAltitude());
+  sdf::ElementPtr pressureElem = elem->GetElement("pressure");
+  sdf::ElementPtr noiseElem = pressureElem->GetElement("noise");
+  noiseElem->Copy(this->dataPtr->noise.ToElement());
+
+  return elem;
+}
