@@ -17,6 +17,7 @@
 #include <array>
 #include <string>
 #include "sdf/Altimeter.hh"
+#include "sdf/parser.hh"
 
 using namespace sdf;
 
@@ -35,7 +36,7 @@ class sdf::Altimeter::Implementation
 
 //////////////////////////////////////////////////
 Altimeter::Altimeter()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -127,3 +128,20 @@ bool Altimeter::operator==(const Altimeter &_alt) const
 
   return true;
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr Altimeter::ToElement() const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("altimeter.sdf", elem);
+
+  sdf::ElementPtr verticalPosElem = elem->GetElement("vertical_position");
+  sdf::ElementPtr verticalPosNoiseElem = verticalPosElem->GetElement("noise");
+  verticalPosNoiseElem->Copy(this->dataPtr->verticalPositionNoise.ToElement());
+
+  sdf::ElementPtr verticalVelElem = elem->GetElement("vertical_velocity");
+  sdf::ElementPtr verticalVelNoiseElem = verticalVelElem->GetElement("noise");
+  verticalVelNoiseElem->Copy(this->dataPtr->verticalVelocityNoise.ToElement());
+
+  return elem;
+}
