@@ -52,6 +52,9 @@ class sdf::Camera::Implementation
   /// \brief The SDF element pointer used during load.
   public: sdf::ElementPtr sdf;
 
+  /// \brief Camera info topic.
+  public: std::string cameraInfoTopic = "";
+
   /// \brief Name of the camera.
   public: std::string name = "";
 
@@ -62,7 +65,7 @@ class sdf::Camera::Implementation
   public: std::string triggerTopic = "";
 
   /// \brief Horizontal fied of view.
-  public: ignition::math::Angle hfov{1.047};
+  public: gz::math::Angle hfov{1.047};
 
   /// \brief Image width.
   public: uint32_t imageWidth{320};
@@ -134,14 +137,17 @@ class sdf::Camera::Implementation
   public: double distortionP2{0.0};
 
   /// \brief The distortion center or principal point
-  public: ignition::math::Vector2d distortionCenter{0.5, 0.5};
+  public: gz::math::Vector2d distortionCenter{0.5, 0.5};
 
   /// \brief Pose of the link
-  public: ignition::math::Pose3d pose = ignition::math::Pose3d::Zero;
+  public: gz::math::Pose3d pose = gz::math::Pose3d::Zero;
 
   /// \brief Frame of the pose.
   public: std::string poseRelativeTo = "";
 
+  /// \brief Frame ID the camera_info message header is expressed.
+  public: std::string opticalFrameId{""};
+
   /// \brief Lens type.
   public: std::string lensType{"stereographic"};
 
@@ -164,7 +170,7 @@ class sdf::Camera::Implementation
   public: std::string lensFun{"tan"};
 
   /// \brief Lens cutoff angle.
-  public: ignition::math::Angle lensCutoffAngle{IGN_PI_2};
+  public: gz::math::Angle lensCutoffAngle{IGN_PI_2};
 
   /// \brief lens environment texture size.
   public: int lensEnvTextureSize{256};
@@ -181,19 +187,40 @@ class sdf::Camera::Implementation
   /// \brief lens instrinsics cy.
   public: double lensIntrinsicsCy{120.0};
 
+  /// \brief lens projection fx
+  public: double lensProjectionFx{277.0};
+
+  /// \brief lens projection fy
+  public: double lensProjectionFy{277.0};
+
+  /// \brief lens projection cx
+  public: double lensProjectionCx{160.0};
+
+  /// \brief lens projection cy
+  public: double lensProjectionCy{120.0};
+
+  /// \brief lens projection tx
+  public: double lensProjectionTx{0.0};
+
+  /// \brief lens projection ty
+  public: double lensProjectionTy{0.0};
+
   /// \brief lens instrinsics s.
   public: double lensIntrinsicsS{1.0};
 
   /// \brief True if this camera has custom intrinsics values
   public: bool hasIntrinsics = false;
 
+  /// \brief True if this camera has custom projection values
+  public: bool hasProjection = false;
+
   /// \brief Visibility mask of a camera. Defaults to 0xFFFFFFFF
   public: uint32_t visibilityMask{UINT32_MAX};
 };
 
 /////////////////////////////////////////////////
 Camera::Camera()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -231,7 +258,12 @@ Errors Camera::Load(ElementPtr _sdf)
   this->dataPtr->triggerTopic = _sdf->Get<std::string>("trigger_topic",
       this->dataPtr->triggerTopic).first;
 
-  this->dataPtr->hfov = _sdf->Get<ignition::math::Angle>("horizontal_fov",
+  this->dataPtr->cameraInfoTopic = _sdf->Get<std::string>("camera_info_topic",
+      this->dataPtr->cameraInfoTopic).first;
+  if (this->dataPtr->cameraInfoTopic == "__default__")
+    this->dataPtr->cameraInfoTopic = "";
+
+  this->dataPtr->hfov = _sdf->Get<gz::math::Angle>("horizontal_fov",
       this->dataPtr->hfov).first;
 
   // Read the distortion
@@ -250,7 +282,7 @@ Errors Camera::Load(ElementPtr _sdf)
     this->dataPtr->distortionP2 = elem->Get<double>("p2",
       this->dataPtr->distortionP2).first;
 
-    this->dataPtr->distortionCenter = elem->Get<ignition::math::Vector2d>(
+    this->dataPtr->distortionCenter = elem->Get<gz::math::Vector2d>(
         "center", this->dataPtr->distortionCenter).first;
   }
 
@@ -348,6 +380,13 @@ Errors Camera::Load(ElementPtr _sdf)
   // Load the pose. Ignore the return value since the pose is optional.
   loadPose(_sdf, this->dataPtr->pose, this->dataPtr->poseRelativeTo);
 
+  // Load the optional optical_frame_id value.
+  if (_sdf->HasElement("optical_frame_id"))
+  {
+    this->dataPtr->opticalFrameId = _sdf->Get<std::string>("optical_frame_id",
+        this->dataPtr->opticalFrameId).first;
+  }
+
   // Load the lens values.
   if (_sdf->HasElement("lens"))
   {
@@ -357,7 +396,7 @@ Errors Camera::Load(ElementPtr _sdf)
         this->dataPtr->lensType).first;
     this->dataPtr->lensScaleToHfov = elem->Get<bool>("scale_to_hfov",
         this->dataPtr->lensScaleToHfov).first;
-    this->dataPtr->lensCutoffAngle = elem->Get<ignition::math::Angle>(
+    this->dataPtr->lensCutoffAngle = elem->Get<gz::math::Angle>(
         "cutoff_angle", this->dataPtr->lensCutoffAngle).first;
     this->dataPtr->lensEnvTextureSize = elem->Get<int>("env_texture_size",
         this->dataPtr->lensEnvTextureSize).first;
@@ -392,6 +431,23 @@ Errors Camera::Load(ElementPtr _sdf)
           this->dataPtr->lensIntrinsicsS).first;
       this->dataPtr->hasIntrinsics = true;
     }
+
+    if (elem->HasElement("projection")) {
+      sdf::ElementPtr projection = elem->GetElement("projection");
+      this->dataPtr->lensProjectionFx = projection->Get<double>("p_fx",
+          this->dataPtr->lensProjectionFx).first;
+      this->dataPtr->lensProjectionFy = projection->Get<double>("p_fy",
+          this->dataPtr->lensProjectionFy).first;
+      this->dataPtr->lensProjectionCx = projection->Get<double>("p_cx",
+          this->dataPtr->lensProjectionCx).first;
+      this->dataPtr->lensProjectionCy = projection->Get<double>("p_cy",
+          this->dataPtr->lensProjectionCy).first;
+      this->dataPtr->lensProjectionTx = projection->Get<double>("tx",
+          this->dataPtr->lensProjectionTx).first;
+      this->dataPtr->lensProjectionTy = projection->Get<double>("ty",
+          this->dataPtr->lensProjectionTy).first;
+      this->dataPtr->hasProjection = true;
+    }
   }
 
   if (_sdf->HasElement("visibility_mask"))
@@ -403,6 +459,18 @@ Errors Camera::Load(ElementPtr _sdf)
   return errors;
 }
 
+/////////////////////////////////////////////////
+std::string Camera::CameraInfoTopic() const
+{
+  return this->dataPtr->cameraInfoTopic;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetCameraInfoTopic(const std::string &_cameraInfoTopic)
+{
+  this->dataPtr->cameraInfoTopic = _cameraInfoTopic;
+}
+
 /////////////////////////////////////////////////
 sdf::ElementPtr Camera::Element() const
 {
@@ -448,13 +516,13 @@ void Camera::SetTriggerTopic(const std::string &_triggerTopic)
 }
 
 /////////////////////////////////////////////////
-ignition::math::Angle Camera::HorizontalFov() const
+gz::math::Angle Camera::HorizontalFov() const
 {
   return this->dataPtr->hfov;
 }
 
 /////////////////////////////////////////////////
-void Camera::SetHorizontalFov(const ignition::math::Angle &_hfov)
+void Camera::SetHorizontalFov(const gz::math::Angle &_hfov)
 {
   this->dataPtr->hfov = _hfov;
 }
@@ -687,12 +755,13 @@ bool Camera::operator==(const Camera &_cam) const
     this->ImageWidth() == _cam.ImageWidth() &&
     this->ImageHeight() == _cam.ImageHeight() &&
     this->PixelFormat() == _cam.PixelFormat() &&
-    ignition::math::equal(this->NearClip(), _cam.NearClip()) &&
-    ignition::math::equal(this->FarClip(), _cam.FarClip()) &&
+    gz::math::equal(this->NearClip(), _cam.NearClip()) &&
+    gz::math::equal(this->FarClip(), _cam.FarClip()) &&
     this->SaveFrames() == _cam.SaveFrames() &&
     this->SaveFramesPath() == _cam.SaveFramesPath() &&
     this->ImageNoise() == _cam.ImageNoise() &&
-    this->VisibilityMask() == _cam.VisibilityMask();
+    this->VisibilityMask() == _cam.VisibilityMask() &&
+    this->OpticalFrameId() == _cam.OpticalFrameId();
 }
 
 //////////////////////////////////////////////////
@@ -774,19 +843,19 @@ void Camera::SetDistortionP2(double _p2)
 }
 
 //////////////////////////////////////////////////
-const ignition::math::Vector2d &Camera::DistortionCenter() const
+const gz::math::Vector2d &Camera::DistortionCenter() const
 {
   return this->dataPtr->distortionCenter;
 }
 
 //////////////////////////////////////////////////
-void Camera::SetDistortionCenter(const ignition::math::Vector2d &_center)
+void Camera::SetDistortionCenter(const gz::math::Vector2d &_center)
 {
   this->dataPtr->distortionCenter = _center;
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Pose3d &Camera::RawPose() const
+const gz::math::Pose3d &Camera::RawPose() const
 {
   return this->dataPtr->pose;
 }
@@ -798,7 +867,7 @@ const std::string &Camera::PoseRelativeTo() const
 }
 
 /////////////////////////////////////////////////
-void Camera::SetRawPose(const ignition::math::Pose3d &_pose)
+void Camera::SetRawPose(const gz::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -809,6 +878,18 @@ void Camera::SetPoseRelativeTo(const std::string &_frame)
   this->dataPtr->poseRelativeTo = _frame;
 }
 
+/////////////////////////////////////////////////
+const std::string Camera::OpticalFrameId() const
+{
+  return this->dataPtr->opticalFrameId;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetOpticalFrameId(const std::string &_frame)
+{
+  this->dataPtr->opticalFrameId = _frame;
+}
+
 /////////////////////////////////////////////////
 std::string Camera::LensType() const
 {
@@ -894,13 +975,13 @@ void Camera::SetLensFunction(const std::string &_fun)
 }
 
 /////////////////////////////////////////////////
-ignition::math::Angle Camera::LensCutoffAngle() const
+gz::math::Angle Camera::LensCutoffAngle() const
 {
   return this->dataPtr->lensCutoffAngle;
 }
 
 /////////////////////////////////////////////////
-void Camera::SetLensCutoffAngle(const ignition::math::Angle &_angle)
+void Camera::SetLensCutoffAngle(const gz::math::Angle &_angle)
 {
   this->dataPtr->lensCutoffAngle = _angle;
 }
@@ -969,6 +1050,84 @@ void Camera::SetLensIntrinsicsCy(double _cy)
   this->dataPtr->hasIntrinsics = true;
 }
 
+/////////////////////////////////////////////////
+double Camera::LensProjectionFx() const
+{
+  return this->dataPtr->lensProjectionFx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionFx(double _fx_p)
+{
+  this->dataPtr->lensProjectionFx = _fx_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionFy() const
+{
+  return this->dataPtr->lensProjectionFy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionFy(double _fy_p)
+{
+  this->dataPtr->lensProjectionFy = _fy_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionCx() const
+{
+  return this->dataPtr->lensProjectionCx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionCx(double _cx_p)
+{
+  this->dataPtr->lensProjectionCx = _cx_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionCy() const
+{
+  return this->dataPtr->lensProjectionCy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionCy(double _cy_p)
+{
+  this->dataPtr->lensProjectionCy = _cy_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionTx() const
+{
+  return this->dataPtr->lensProjectionTx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionTx(double _tx)
+{
+  this->dataPtr->lensProjectionTx = _tx;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionTy() const
+{
+  return this->dataPtr->lensProjectionTy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionTy(double _ty)
+{
+  this->dataPtr->lensProjectionTy = _ty;
+  this->dataPtr->hasProjection = true;
+}
+
 /////////////////////////////////////////////////
 double Camera::LensIntrinsicsSkew() const
 {
@@ -1042,6 +1201,12 @@ bool Camera::HasLensIntrinsics() const
   return this->dataPtr->hasIntrinsics;
 }
 
+/////////////////////////////////////////////////
+bool Camera::HasLensProjection() const
+{
+  return this->dataPtr->hasProjection;
+}
+
 /////////////////////////////////////////////////
 sdf::ElementPtr Camera::ToElement() const
 {
@@ -1055,7 +1220,7 @@ sdf::ElementPtr Camera::ToElement() const
     poseElem->GetAttribute("relative_to")->Set<std::string>(
         this->dataPtr->poseRelativeTo);
   }
-  poseElem->Set<ignition::math::Pose3d>(this->RawPose());
+  poseElem->Set<gz::math::Pose3d>(this->RawPose());
   elem->GetElement("horizontal_fov")->Set<double>(
       this->HorizontalFov().Radian());
   sdf::ElementPtr imageElem = elem->GetElement("image");
@@ -1064,6 +1229,12 @@ sdf::ElementPtr Camera::ToElement() const
   imageElem->GetElement("format")->Set<std::string>(this->PixelFormatStr());
   imageElem->GetElement("anti_aliasing")->Set<uint32_t>(
       this->AntiAliasingValue());
+  elem->GetElement("camera_info_topic")->Set<std::string>(
+      this->CameraInfoTopic());
+  elem->GetElement("trigger_topic")->Set<std::string>(
+      this->TriggerTopic());
+  elem->GetElement("triggered")->Set<bool>(
+      this->Triggered());
 
   sdf::ElementPtr clipElem = elem->GetElement("clip");
   clipElem->GetElement("near")->Set<double>(this->NearClip());
@@ -1113,7 +1284,7 @@ sdf::ElementPtr Camera::ToElement() const
   distortionElem->GetElement("k3")->Set<double>(this->DistortionK3());
   distortionElem->GetElement("p1")->Set<double>(this->DistortionP1());
   distortionElem->GetElement("p2")->Set<double>(this->DistortionP2());
-  distortionElem->GetElement("center")->Set<ignition::math::Vector2d>(
+  distortionElem->GetElement("center")->Set<gz::math::Vector2d>(
       this->DistortionCenter());
 
   sdf::ElementPtr lensElem = elem->GetElement("lens");
@@ -1142,6 +1313,17 @@ sdf::ElementPtr Camera::ToElement() const
     intrinsicsElem->GetElement("cy")->Set<double>(this->LensIntrinsicsCy());
     intrinsicsElem->GetElement("s")->Set<double>(this->LensIntrinsicsSkew());
   }
+  if (this->HasLensProjection())
+  {
+    sdf::ElementPtr projectionElem = lensElem->GetElement("projection");
+    projectionElem->GetElement("p_fx")->Set<double>(this->LensProjectionFx());
+    projectionElem->GetElement("p_fy")->Set<double>(this->LensProjectionFy());
+    projectionElem->GetElement("p_cx")->Set<double>(this->LensProjectionCx());
+    projectionElem->GetElement("p_cy")->Set<double>(this->LensProjectionCy());
+    projectionElem->GetElement("tx")->Set<double>(this->LensProjectionTx());
+    projectionElem->GetElement("ty")->Set<double>(this->LensProjectionTy());
+  }
+
 
   if (this->HasSegmentationType())
   {
@@ -1149,5 +1331,8 @@ sdf::ElementPtr Camera::ToElement() const
         this->SegmentationType());
   }
 
+  elem->GetElement("optical_frame_id")->Set<std::string>(
+      this->OpticalFrameId());
+
   return elem;
 }
