@@ -152,6 +152,8 @@ void Element::AddValue(const std::string &_type,
   this->dataPtr->value =
       std::make_shared<Param>(this->dataPtr->name, _type, _defaultValue,
                               _required, _minValue, _maxValue, _description);
+  SDF_ASSERT(this->dataPtr->value->SetParentElement(shared_from_this()),
+      "Cannot set parent Element of value to itself.");
 }
 
 /////////////////////////////////////////////////
@@ -161,8 +163,11 @@ ParamPtr Element::CreateParam(const std::string &_key,
                               bool _required,
                               const std::string &_description)
 {
-  return ParamPtr(
-      new Param(_key, _type, _defaultValue, _required, _description));
+  ParamPtr param = std::make_shared<Param>(
+      _key, _type, _defaultValue, _required, _description);
+  SDF_ASSERT(param->SetParentElement(shared_from_this()),
+      "Cannot set parent Element of created Param to itself.");
+  return param;
 }
 
 /////////////////////////////////////////////////
@@ -184,7 +189,6 @@ ElementPtr Element::Clone() const
   clone->dataPtr->name = this->dataPtr->name;
   clone->dataPtr->required = this->dataPtr->required;
   clone->dataPtr->copyChildren = this->dataPtr->copyChildren;
-  clone->dataPtr->includeFilename = this->dataPtr->includeFilename;
   clone->dataPtr->referenceSDF = this->dataPtr->referenceSDF;
   clone->dataPtr->path = this->dataPtr->path;
   clone->dataPtr->lineNumber = this->dataPtr->lineNumber;
@@ -196,7 +200,11 @@ ElementPtr Element::Clone() const
   for (aiter = this->dataPtr->attributes.begin();
        aiter != this->dataPtr->attributes.end(); ++aiter)
   {
-    clone->dataPtr->attributes.push_back((*aiter)->Clone());
+    auto clonedAttribute = (*aiter)->Clone();
+    SDF_ASSERT(clonedAttribute->SetParentElement(clone),
+        "Cannot set parent Element of cloned attribute Param to cloned "
+        "Element.");
+    clone->dataPtr->attributes.push_back(clonedAttribute);
   }
 
   ElementPtr_V::const_iterator eiter;
@@ -216,6 +224,8 @@ ElementPtr Element::Clone() const
   if (this->dataPtr->value)
   {
     clone->dataPtr->value = this->dataPtr->value->Clone();
+    SDF_ASSERT(clone->dataPtr->value->SetParentElement(clone),
+        "Cannot set parent Element of cloned value Param to cloned Element.");
   }
 
   if (this->dataPtr->includeElement)
@@ -233,7 +243,6 @@ void Element::Copy(const ElementPtr _elem)
   this->dataPtr->description = _elem->GetDescription();
   this->dataPtr->required = _elem->GetRequired();
   this->dataPtr->copyChildren = _elem->GetCopyChildren();
-  this->dataPtr->includeFilename = _elem->dataPtr->includeFilename;
   this->dataPtr->referenceSDF = _elem->ReferenceSDF();
   this->dataPtr->originalVersion = _elem->OriginalVersion();
   this->dataPtr->path = _elem->FilePath();
@@ -250,6 +259,8 @@ void Element::Copy(const ElementPtr _elem)
     }
     ParamPtr param = this->GetAttribute((*iter)->GetKey());
     (*param) = (**iter);
+    SDF_ASSERT(param->SetParentElement(shared_from_this()),
+        "Cannot set parent Element of copied attribute Param to itself.");
   }
 
   if (_elem->GetValue())
@@ -262,6 +273,8 @@ void Element::Copy(const ElementPtr _elem)
     {
       *(this->dataPtr->value) = *(_elem->GetValue());
     }
+    SDF_ASSERT(this->dataPtr->value->SetParentElement(shared_from_this()),
+        "Cannot set parent Element of copied value Param to itself.");
   }
 
   this->dataPtr->elementDescriptions.clear();
@@ -486,31 +499,22 @@ void Element::PrintDocLeftPane(std::string &_html, int _spacing,
   _html += "</div>\n";
 }
 
+/////////////////////////////////////////////////
 void Element::PrintValuesImpl(const std::string &_prefix,
                               bool _includeDefaultElements,
                               bool _includeDefaultAttributes,
+                              const PrintConfig &_config,
                               std::ostringstream &_out) const
 {
-  if (this->GetExplicitlySetInFile() || _includeDefaultElements)
+  if (_config.PreserveIncludes() && this->GetIncludeElement() != nullptr)
+  {
+    _out << this->GetIncludeElement()->ToString(_prefix, _config);
+  }
+  else if (this->GetExplicitlySetInFile() || _includeDefaultElements)
   {
     _out << _prefix << "<" << this->dataPtr->name;
 
-    Param_V::const_iterator aiter;
-    for (aiter = this->dataPtr->attributes.begin();
-         aiter != this->dataPtr->attributes.end(); ++aiter)
-    {
-      // Only print attribute values if they were set
-      // TODO(anyone): GetRequired is added here to support up-conversions where
-      // a new required attribute with a default value is added. We would have
-      // better separation of concerns if the conversion process set the
-      // required attributes with their default values.
-      if ((*aiter)->GetSet() || (*aiter)->GetRequired() ||
-          _includeDefaultAttributes)
-      {
-        _out << " " << (*aiter)->GetKey() << "='"
-             << (*aiter)->GetAsString() << "'";
-      }
-    }
+    this->dataPtr->PrintAttributes(_includeDefaultAttributes, _config, _out);
 
     if (this->dataPtr->elements.size() > 0)
     {
@@ -519,13 +523,11 @@ void Element::PrintValuesImpl(const std::string &_prefix,
       for (eiter = this->dataPtr->elements.begin();
            eiter != this->dataPtr->elements.end(); ++eiter)
       {
-        if ((*eiter)->GetExplicitlySetInFile() || _includeDefaultElements)
-        {
-          (*eiter)->ToString(_prefix + "  ",
-                             _includeDefaultElements,
-                             _includeDefaultAttributes,
-                             _out);
-        }
+        (*eiter)->ToString(_prefix + "  ",
+                           _includeDefaultElements,
+                           _includeDefaultAttributes,
+                           _config,
+                           _out);
       }
       _out << _prefix << "</" << this->dataPtr->name << ">\n";
     }
@@ -533,7 +535,7 @@ void Element::PrintValuesImpl(const std::string &_prefix,
     {
       if (this->dataPtr->value)
       {
-        _out << ">" << this->dataPtr->value->GetAsString()
+        _out << ">" << this->dataPtr->value->GetAsString(_config)
              << "</" << this->dataPtr->name << ">\n";
       }
       else
@@ -545,43 +547,92 @@ void Element::PrintValuesImpl(const std::string &_prefix,
 }
 
 /////////////////////////////////////////////////
-void Element::PrintValues(std::string _prefix) const
+void ElementPrivate::PrintAttributes(bool _includeDefaultAttributes,
+                                     const PrintConfig &_config,
+                                     std::ostringstream &_out) const
+{
+  // Attribute exceptions are used in the event of a non-default PrintConfig
+  // which modifies the Attributes of this Element that are printed out. The
+  // modifications to an Attribute by a PrintConfig will overwrite the original
+  // existing Attribute when this Element is printed.
+  std::set<std::string> attributeExceptions;
+  if (this->name == "pose")
+  {
+    if (_config.RotationInDegrees() || _config.RotationSnapToDegrees())
+    {
+      attributeExceptions.insert("degrees");
+      _out << " " << "degrees='true'";
+
+      attributeExceptions.insert("rotation_format");
+      _out << " " << "rotation_format='euler_rpy'";
+    }
+  }
+
+  Param_V::const_iterator aiter;
+  for (aiter = this->attributes.begin();
+       aiter != this->attributes.end(); ++aiter)
+  {
+    // Only print attribute values if they were set
+    // TODO(anyone): GetRequired is added here to support up-conversions where
+    // a new required attribute with a default value is added. We would have
+    // better separation of concerns if the conversion process set the
+    // required attributes with their default values.
+    if ((*aiter)->GetSet() || (*aiter)->GetRequired() ||
+        _includeDefaultAttributes)
+    {
+      const std::string key = (*aiter)->GetKey();
+      const auto it = attributeExceptions.find(key);
+      if (it == attributeExceptions.end())
+      {
+        _out << " " << key << "='" << (*aiter)->GetAsString(_config) << "'";
+      }
+    }
+  }
+}
+
+/////////////////////////////////////////////////
+void Element::PrintValues(std::string _prefix, const PrintConfig &_config) const
 {
   std::ostringstream ss;
-  PrintValuesImpl(_prefix, true, false, ss);
+  PrintValuesImpl(_prefix, true, false, _config, ss);
   std::cout << ss.str();
 }
 
 /////////////////////////////////////////////////
 void Element::PrintValues(const std::string &_prefix,
                           bool _includeDefaultElements,
-                          bool _includeDefaultAttributes) const
+                          bool _includeDefaultAttributes,
+                          const PrintConfig &_config) const
 {
   std::ostringstream ss;
   PrintValuesImpl(_prefix,
                   _includeDefaultElements,
                   _includeDefaultAttributes,
+                  _config,
                   ss);
   std::cout << ss.str();
 }
 
 /////////////////////////////////////////////////
-std::string Element::ToString(const std::string &_prefix) const
+std::string Element::ToString(const std::string &_prefix,
+                              const PrintConfig &_config) const
 {
   std::ostringstream out;
-  this->ToString(_prefix, true, false, out);
+  this->ToString(_prefix, true, false, _config, out);
   return out.str();
 }
 
 /////////////////////////////////////////////////
 std::string Element::ToString(const std::string &_prefix,
                               bool _includeDefaultElements,
-                              bool _includeDefaultAttributes) const
+                              bool _includeDefaultAttributes,
+                              const PrintConfig &_config) const
 {
   std::ostringstream out;
   this->ToString(_prefix,
                  _includeDefaultElements,
                  _includeDefaultAttributes,
+                 _config,
                  out);
   return out.str();
 }
@@ -590,20 +641,14 @@ std::string Element::ToString(const std::string &_prefix,
 void Element::ToString(const std::string &_prefix,
                        bool _includeDefaultElements,
                        bool _includeDefaultAttributes,
+                       const PrintConfig &_config,
                        std::ostringstream &_out) const
 {
-  if (this->dataPtr->includeFilename.empty())
-  {
-    PrintValuesImpl(_prefix,
-                    _includeDefaultElements,
-                    _includeDefaultAttributes,
-                    _out);
-  }
-  else
-  {
-    _out << _prefix << "<include filename='"
-         << this->dataPtr->includeFilename << "'/>\n";
-  }
+  PrintValuesImpl(_prefix,
+                  _includeDefaultElements,
+                  _includeDefaultAttributes,
+                  _config,
+                  _out);
 }
 
 /////////////////////////////////////////////////
@@ -667,6 +712,12 @@ size_t Element::GetAttributeCount() const
   return this->dataPtr->attributes.size();
 }
 
+/////////////////////////////////////////////////
+const Param_V &Element::GetAttributes() const
+{
+  return this->dataPtr->attributes;
+}
+
 /////////////////////////////////////////////////
 ParamPtr Element::GetAttribute(unsigned int _index) const
 {
@@ -908,6 +959,14 @@ void Element::InsertElement(ElementPtr _elem)
   this->dataPtr->elements.push_back(_elem);
 }
 
+/////////////////////////////////////////////////
+void Element::InsertElement(ElementPtr _elem,  bool _setParentToSelf)
+{
+  if (_setParentToSelf)
+    _elem->SetParent(shared_from_this());
+  this->dataPtr->elements.push_back(_elem);
+}
+
 /////////////////////////////////////////////////
 bool Element::HasElementDescription(const std::string &_name) const
 {
@@ -1039,18 +1098,6 @@ void Element::AddElementDescription(ElementPtr _elem)
   this->dataPtr->elementDescriptions.push_back(_elem);
 }
 
-/////////////////////////////////////////////////
-void Element::SetInclude(const std::string &_filename)
-{
-  this->dataPtr->includeFilename = _filename;
-}
-
-/////////////////////////////////////////////////
-std::string Element::GetInclude() const
-{
-  return this->dataPtr->includeFilename;
-}
-
 /////////////////////////////////////////////////
 void Element::SetIncludeElement(sdf::ElementPtr _includeElem)
 {
