@@ -15,21 +15,35 @@
  *
  */
 
-#include "sdf/ExceptionPrivate.hh"
+#include <cstdint>
+#include <string>
+
 #include "sdf/Console.hh"
 #include "sdf/Exception.hh"
 
 using namespace sdf;
 
+class sdf::Exception::Implementation
+{
+  /// \brief The error function
+  public: std::string file;
+
+  /// \brief Line the error occured on
+  public: std::int64_t line;
+
+  /// \brief The error string
+  public: std::string str;
+};
+
 //////////////////////////////////////////////////
 Exception::Exception()
-  : dataPtr(new ExceptionPrivate)
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
 //////////////////////////////////////////////////
-Exception::Exception(const char *_file, int64_t _line, std::string _msg)
-  : dataPtr(new ExceptionPrivate)
+Exception::Exception(const char *_file, std::int64_t _line, std::string _msg)
+  : Exception()
 {
   this->dataPtr->file = _file;
   this->dataPtr->line = _line;
@@ -37,22 +51,6 @@ Exception::Exception(const char *_file, int64_t _line, std::string _msg)
   this->Print();
 }
 
-//////////////////////////////////////////////////
-Exception::Exception(const Exception &_e)
-  : dataPtr(new ExceptionPrivate)
-{
-  this->dataPtr->file = _e.dataPtr->file;
-  this->dataPtr->line = _e.dataPtr->line;
-  this->dataPtr->str = _e.dataPtr->str;
-}
-
-//////////////////////////////////////////////////
-Exception::~Exception()
-{
-  delete this->dataPtr;
-  this->dataPtr = nullptr;
-}
-
 //////////////////////////////////////////////////
 void Exception::Print() const
 {
@@ -79,7 +77,7 @@ InternalError::InternalError()
 }
 
 //////////////////////////////////////////////////
-InternalError::InternalError(const char *_file, int64_t _line,
+InternalError::InternalError(const char *_file, std::int64_t _line,
                              const std::string _msg) :
   Exception(_file, _line, _msg)
 {
@@ -92,7 +90,7 @@ InternalError::~InternalError()
 
 //////////////////////////////////////////////////
 AssertionInternalError::AssertionInternalError(
-    const char * _file, int64_t _line,
+    const char * _file, std::int64_t _line,
     const std::string _expr,
     const std::string _function,
     const std::string _msg) :
