@@ -72,7 +72,7 @@ TEST(DOMGeometry, CopyConstructor)
   sdf::Geometry geometry;
   geometry.SetType(sdf::GeometryType::BOX);
   sdf::Box boxShape;
-  boxShape.SetSize(ignition::math::Vector3d(1, 2, 3));
+  boxShape.SetSize(gz::math::Vector3d(1, 2, 3));
   geometry.SetBoxShape(boxShape);
 
   sdf::Geometry geometry2(geometry);
@@ -85,7 +85,7 @@ TEST(DOMGeometry, AssignmentOperator)
   sdf::Geometry geometry;
   geometry.SetType(sdf::GeometryType::BOX);
   sdf::Box boxShape;
-  boxShape.SetSize(ignition::math::Vector3d(1, 2, 3));
+  boxShape.SetSize(gz::math::Vector3d(1, 2, 3));
   geometry.SetBoxShape(boxShape);
 
   sdf::Geometry geometry2;
@@ -99,7 +99,7 @@ TEST(DOMGeometry, MoveAssignmentOperator)
   sdf::Geometry geometry;
   geometry.SetType(sdf::GeometryType::BOX);
   sdf::Box boxShape;
-  boxShape.SetSize(ignition::math::Vector3d(1, 2, 3));
+  boxShape.SetSize(gz::math::Vector3d(1, 2, 3));
   geometry.SetBoxShape(boxShape);
 
   sdf::Geometry geometry2;
@@ -154,12 +154,12 @@ TEST(DOMGeometry, Box)
   geom.SetType(sdf::GeometryType::BOX);
 
   sdf::Box boxShape;
-  boxShape.SetSize(ignition::math::Vector3d(1, 2, 3));
+  boxShape.SetSize(gz::math::Vector3d(1, 2, 3));
   geom.SetBoxShape(boxShape);
 
   EXPECT_EQ(sdf::GeometryType::BOX, geom.Type());
   EXPECT_NE(nullptr, geom.BoxShape());
-  EXPECT_EQ(ignition::math::Vector3d(1, 2, 3), geom.BoxShape()->Size());
+  EXPECT_EQ(gz::math::Vector3d(1, 2, 3), geom.BoxShape()->Size());
 }
 
 /////////////////////////////////////////////////
@@ -218,7 +218,7 @@ TEST(DOMGeometry, Ellipsoid)
   geom.SetType(sdf::GeometryType::ELLIPSOID);
 
   sdf::Ellipsoid ellipsoidShape;
-  const ignition::math::Vector3d expectedRadii(1, 2, 3);
+  const gz::math::Vector3d expectedRadii(1, 2, 3);
   ellipsoidShape.SetRadii(expectedRadii);
   geom.SetEllipsoidShape(ellipsoidShape);
 
@@ -234,7 +234,7 @@ TEST(DOMGeometry, Mesh)
   geom.SetType(sdf::GeometryType::MESH);
 
   sdf::Mesh meshShape;
-  meshShape.SetScale(ignition::math::Vector3d(1, 2, 3));
+  meshShape.SetScale(gz::math::Vector3d(1, 2, 3));
   meshShape.SetUri("banana");
   meshShape.SetSubmesh("orange");
   meshShape.SetCenterSubmesh(true);
@@ -242,7 +242,7 @@ TEST(DOMGeometry, Mesh)
 
   EXPECT_EQ(sdf::GeometryType::MESH, geom.Type());
   EXPECT_NE(nullptr, geom.MeshShape());
-  EXPECT_EQ(ignition::math::Vector3d(1, 2, 3), geom.MeshShape()->Scale());
+  EXPECT_EQ(gz::math::Vector3d(1, 2, 3), geom.MeshShape()->Scale());
   EXPECT_EQ("banana", geom.MeshShape()->Uri());
   EXPECT_EQ("orange", geom.MeshShape()->Submesh());
   EXPECT_TRUE(geom.MeshShape()->CenterSubmesh());
@@ -255,14 +255,14 @@ TEST(DOMGeometry, Plane)
   geom.SetType(sdf::GeometryType::PLANE);
 
   sdf::Plane planeShape;
-  planeShape.SetNormal(ignition::math::Vector3d::UnitX);
-  planeShape.SetSize(ignition::math::Vector2d(9, 8));
+  planeShape.SetNormal(gz::math::Vector3d::UnitX);
+  planeShape.SetSize(gz::math::Vector2d(9, 8));
   geom.SetPlaneShape(planeShape);
 
   EXPECT_EQ(sdf::GeometryType::PLANE, geom.Type());
   EXPECT_NE(nullptr, geom.PlaneShape());
-  EXPECT_EQ(ignition::math::Vector3d::UnitX, geom.PlaneShape()->Normal());
-  EXPECT_EQ(ignition::math::Vector2d(9, 8), geom.PlaneShape()->Size());
+  EXPECT_EQ(gz::math::Vector3d::UnitX, geom.PlaneShape()->Normal());
+  EXPECT_EQ(gz::math::Vector2d(9, 8), geom.PlaneShape()->Size());
 }
 
 /////////////////////////////////////////////////
@@ -289,12 +289,12 @@ TEST(DOMGeometry, Polyline)
   EXPECT_EQ(2u, polylineShape.size());
   EXPECT_DOUBLE_EQ(1.2, polylineShape[0].Height());
   ASSERT_EQ(2u, polylineShape[0].PointCount());
-  EXPECT_EQ(ignition::math::Vector2d(3.4, 5.6), polylineShape[0].Points()[0]);
-  EXPECT_EQ(ignition::math::Vector2d(7.8, 9.0), polylineShape[0].Points()[1]);
+  EXPECT_EQ(gz::math::Vector2d(3.4, 5.6), polylineShape[0].Points()[0]);
+  EXPECT_EQ(gz::math::Vector2d(7.8, 9.0), polylineShape[0].Points()[1]);
   EXPECT_DOUBLE_EQ(2.1, polylineShape[1].Height());
   ASSERT_EQ(2u, polylineShape[1].PointCount());
-  EXPECT_EQ(ignition::math::Vector2d(4.3, 6.5), polylineShape[1].Points()[0]);
-  EXPECT_EQ(ignition::math::Vector2d(8.7, 0.9), polylineShape[1].Points()[1]);
+  EXPECT_EQ(gz::math::Vector2d(4.3, 6.5), polylineShape[1].Points()[0]);
+  EXPECT_EQ(gz::math::Vector2d(8.7, 0.9), polylineShape[1].Points()[1]);
 }
 
 /////////////////////////////////////////////////
