@@ -17,6 +17,7 @@
 #include <array>
 #include <string>
 #include "sdf/Imu.hh"
+#include "sdf/parser.hh"
 
 using namespace sdf;
 
@@ -48,7 +49,7 @@ class sdf::Imu::Implementation
   public: Noise angularVelZNoise;
 
   /// \brief The gravity dir
-  public: ignition::math::Vector3d gravityDirX{ignition::math::Vector3d::UnitX};
+  public: gz::math::Vector3d gravityDirX{gz::math::Vector3d::UnitX};
 
   /// \brief Name of the parent frame for the gravityDirX vector.
   public: std::string gravityDirXParentFrame;
@@ -57,7 +58,7 @@ class sdf::Imu::Implementation
   public: std::string localization = "CUSTOM";
 
   /// \brief Custom RPY
-  public: ignition::math::Vector3d customRpy;
+  public: gz::math::Vector3d customRpy;
 
   /// \brief Name of the parent frame for the customRpy vector.
   public: std::string customRpyParentFrame;
@@ -71,7 +72,7 @@ class sdf::Imu::Implementation
 
 //////////////////////////////////////////////////
 Imu::Imu()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -164,7 +165,7 @@ Errors Imu::Load(ElementPtr _sdf)
 
     if (elem->HasElement("grav_dir_x"))
     {
-      this->dataPtr->gravityDirX = elem->Get<ignition::math::Vector3d>(
+      this->dataPtr->gravityDirX = elem->Get<gz::math::Vector3d>(
           "grav_dir_x", this->dataPtr->gravityDirX).first;
       this->dataPtr->gravityDirXParentFrame =
         elem->GetElement("grav_dir_x")->Get<std::string>("parent_frame",
@@ -173,7 +174,7 @@ Errors Imu::Load(ElementPtr _sdf)
 
     if (elem->HasElement("custom_rpy"))
     {
-      this->dataPtr->customRpy = elem->Get<ignition::math::Vector3d>(
+      this->dataPtr->customRpy = elem->Get<gz::math::Vector3d>(
           "custom_rpy", this->dataPtr->customRpy).first;
       this->dataPtr->customRpyParentFrame =
         elem->GetElement("custom_rpy")->Get<std::string>("parent_frame",
@@ -295,7 +296,7 @@ void Imu::SetAngularVelocityZNoise(const Noise &_noise)
 }
 
 //////////////////////////////////////////////////
-const ignition::math::Vector3d &Imu::GravityDirX() const
+const gz::math::Vector3d &Imu::GravityDirX() const
 {
   return this->dataPtr->gravityDirX;
 }
@@ -313,7 +314,7 @@ void Imu::SetGravityDirXParentFrame(const std::string &_frame)
 }
 
 //////////////////////////////////////////////////
-void Imu::SetGravityDirX(const ignition::math::Vector3d &_grav)
+void Imu::SetGravityDirX(const gz::math::Vector3d &_grav)
 {
   this->dataPtr->gravityDirX = _grav;
 }
@@ -331,13 +332,13 @@ void Imu::SetLocalization(const std::string &_localization)
 }
 
 //////////////////////////////////////////////////
-const ignition::math::Vector3d &Imu::CustomRpy() const
+const gz::math::Vector3d &Imu::CustomRpy() const
 {
   return this->dataPtr->customRpy;
 }
 
 //////////////////////////////////////////////////
-void Imu::SetCustomRpy(const ignition::math::Vector3d &_rpy)
+void Imu::SetCustomRpy(const gz::math::Vector3d &_rpy)
 {
   this->dataPtr->customRpy = _rpy;
 }
@@ -365,3 +366,58 @@ bool Imu::OrientationEnabled() const
 {
   return this->dataPtr->orientationEnabled;
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr Imu::ToElement() const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("imu.sdf", elem);
+
+  sdf::ElementPtr orientationRefFrameElem =
+    elem->GetElement("orientation_reference_frame");
+  orientationRefFrameElem->GetElement("localization")->Set<std::string>(
+      this->Localization());
+
+  sdf::ElementPtr customRPY =
+    orientationRefFrameElem->GetElement("custom_rpy");
+  customRPY->Set<gz::math::Vector3d>(this->CustomRpy());
+  customRPY->GetAttribute("parent_frame")->Set<std::string>(
+      this->CustomRpyParentFrame());
+
+  sdf::ElementPtr gravDirX =
+    orientationRefFrameElem->GetElement("grav_dir_x");
+  gravDirX->Set<gz::math::Vector3d>(this->GravityDirX());
+  gravDirX->GetAttribute("parent_frame")->Set<std::string>(
+      this->GravityDirXParentFrame());
+
+  sdf::ElementPtr angularVelElem = elem->GetElement("angular_velocity");
+  sdf::ElementPtr angularVelXElem = angularVelElem->GetElement("x");
+  sdf::ElementPtr angularVelXNoiseElem = angularVelXElem->GetElement("noise");
+  angularVelXNoiseElem->Copy(this->dataPtr->angularVelXNoise.ToElement());
+
+  sdf::ElementPtr angularVelYElem = angularVelElem->GetElement("y");
+  sdf::ElementPtr angularVelYNoiseElem = angularVelYElem->GetElement("noise");
+  angularVelYNoiseElem->Copy(this->dataPtr->angularVelYNoise.ToElement());
+
+  sdf::ElementPtr angularVelZElem = angularVelElem->GetElement("z");
+  sdf::ElementPtr angularVelZNoiseElem = angularVelZElem->GetElement("noise");
+  angularVelZNoiseElem->Copy(this->dataPtr->angularVelZNoise.ToElement());
+
+  sdf::ElementPtr linearAccElem = elem->GetElement("linear_acceleration");
+  sdf::ElementPtr linearAccXElem = linearAccElem->GetElement("x");
+  sdf::ElementPtr linearAccXNoiseElem = linearAccXElem->GetElement("noise");
+  linearAccXNoiseElem->Copy(this->dataPtr->linearAccelXNoise.ToElement());
+
+  sdf::ElementPtr linearAccYElem = linearAccElem->GetElement("y");
+  sdf::ElementPtr linearAccYNoiseElem = linearAccYElem->GetElement("noise");
+  linearAccYNoiseElem->Copy(this->dataPtr->linearAccelYNoise.ToElement());
+
+  sdf::ElementPtr linearAccZElem = linearAccElem->GetElement("z");
+  sdf::ElementPtr linearAccZNoiseElem = linearAccZElem->GetElement("noise");
+  linearAccZNoiseElem->Copy(this->dataPtr->linearAccelZNoise.ToElement());
+
+  elem->GetElement("enable_orientation")->Set<bool>(
+      this->OrientationEnabled());
+
+  return elem;
+}
