@@ -17,12 +17,13 @@
 #include <algorithm>
 #include <iterator>
 
-#include <ignition/math/Pose3.hh>
-#include <ignition/math/Vector3.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/math/Vector3.hh>
 
 #include "sdf/Assert.hh"
 #include "sdf/Error.hh"
 #include "sdf/JointAxis.hh"
+#include "sdf/parser.hh"
 #include "FrameSemantics.hh"
 #include "ScopedGraph.hh"
 #include "Utils.hh"
@@ -31,14 +32,11 @@ using namespace sdf;
 
 class sdf::JointAxis::Implementation
 {
-  /// \brief Default joint position for this joint axis.
-  public: double initialPosition = 0.0;
-
   /// \brief Represents the x,y,z components of the axis unit vector.
   /// The axis is expressed in the joint frame unless the
   /// use_parent_model_frame flag is set to true. The vector should be
   /// normalized.
-  public: ignition::math::Vector3d xyz = ignition::math::Vector3d::UnitZ;
+  public: gz::math::Vector3d xyz = gz::math::Vector3d::UnitZ;
 
   /// \brief Frame in which xyz is expressed in.
   public: std::string xyzExpressedIn = "";
@@ -93,7 +91,7 @@ class sdf::JointAxis::Implementation
 
 /////////////////////////////////////////////////
 JointAxis::JointAxis()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -104,14 +102,10 @@ Errors JointAxis::Load(ElementPtr _sdf)
 
   this->dataPtr->sdf = _sdf;
 
-  // Read the initial position. This is optional, with a default value of 0.
-  this->dataPtr->initialPosition = _sdf->Get<double>(
-      "initial_position", 0.0).first;
-
   // Read the xyz values.
   if (_sdf->HasElement("xyz"))
   {
-    using ignition::math::Vector3d;
+    using gz::math::Vector3d;
     auto errs = this->SetXyz(_sdf->Get<Vector3d>("xyz", Vector3d::UnitZ).first);
     std::copy(errs.begin(), errs.end(), std::back_inserter(errors));
     auto e = _sdf->GetElement("xyz");
@@ -168,24 +162,13 @@ Errors JointAxis::Load(ElementPtr _sdf)
 }
 
 /////////////////////////////////////////////////
-double JointAxis::InitialPosition() const
-{
-  return this->dataPtr->initialPosition;
-}
-/////////////////////////////////////////////////
-void JointAxis::SetInitialPosition(const double _pos)
-{
-  this->dataPtr->initialPosition = _pos;
-}
-
-/////////////////////////////////////////////////
-ignition::math::Vector3d JointAxis::Xyz() const
+gz::math::Vector3d JointAxis::Xyz() const
 {
   return this->dataPtr->xyz;
 }
 
 /////////////////////////////////////////////////
-sdf::Errors JointAxis::SetXyz(const ignition::math::Vector3d &_xyz)
+sdf::Errors JointAxis::SetXyz(const gz::math::Vector3d &_xyz)
 {
   if (sdf::equal(_xyz.Length(), 0.0))
   {
@@ -343,7 +326,7 @@ void JointAxis::SetPoseRelativeToGraph(
 
 /////////////////////////////////////////////////
 Errors JointAxis::ResolveXyz(
-    ignition::math::Vector3d &_xyz,
+    gz::math::Vector3d &_xyz,
     const std::string &_resolveTo) const
 {
   Errors errors;
@@ -375,7 +358,7 @@ Errors JointAxis::ResolveXyz(
     resolveTo = this->dataPtr->xmlParentName;
   }
 
-  ignition::math::Pose3d pose;
+  gz::math::Pose3d pose;
   errors = resolvePose(pose, graph, axisExpressedIn, resolveTo);
 
   if (errors.empty())
@@ -391,3 +374,43 @@ sdf::ElementPtr JointAxis::Element() const
 {
   return this->dataPtr->sdf;
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr JointAxis::ToElement(unsigned int _index) const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("joint.sdf", elem);
+
+  std::string axisElemName = "axis";
+  if (_index > 0u)
+    axisElemName += std::to_string(_index + 1);
+  sdf::ElementPtr axisElem = elem->GetElement(axisElemName);
+  sdf::ElementPtr xyzElem = axisElem->GetElement("xyz");
+  xyzElem->Set<gz::math::Vector3d>(this->Xyz());
+  if (!this->XyzExpressedIn().empty())
+  {
+    xyzElem->GetAttribute("expressed_in")->Set<std::string>(
+        this->XyzExpressedIn());
+  }
+  else if (this->dataPtr->useParentModelFrame)
+  {
+     xyzElem->GetAttribute("expressed_in")->Set<std::string>(
+        "__model__");
+  }
+  sdf::ElementPtr dynElem = axisElem->GetElement("dynamics");
+  dynElem->GetElement("damping")->Set<double>(this->Damping());
+  dynElem->GetElement("friction")->Set<double>(this->Friction());
+  dynElem->GetElement("spring_reference")->Set<double>(
+      this->SpringReference());
+  dynElem->GetElement("spring_stiffness")->Set<double>(
+      this->SpringStiffness());
+
+  sdf::ElementPtr limitElem = axisElem->GetElement("limit");
+  limitElem->GetElement("lower")->Set<double>(this->Lower());
+  limitElem->GetElement("upper")->Set<double>(this->Upper());
+  limitElem->GetElement("effort")->Set<double>(this->Effort());
+  limitElem->GetElement("velocity")->Set<double>(this->MaxVelocity());
+  limitElem->GetElement("stiffness")->Set<double>(this->Stiffness());
+  limitElem->GetElement("dissipation")->Set<double>(this->Dissipation());
+  return axisElem;
+}
