@@ -17,9 +17,9 @@
 #include <memory>
 #include <string>
 #include <vector>
-#include <ignition/math/Inertial.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/math/Vector3.hh>
+#include <gz/math/Inertial.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/math/Vector3.hh>
 
 #include "sdf/Collision.hh"
 #include "sdf/Error.hh"
@@ -43,7 +43,7 @@ class sdf::Link::Implementation
   public: std::string name = "";
 
   /// \brief Pose of the link
-  public: ignition::math::Pose3d pose = ignition::math::Pose3d::Zero;
+  public: gz::math::Pose3d pose = gz::math::Pose3d::Zero;
 
   /// \brief Frame of the pose.
   public: std::string poseRelativeTo = "";
@@ -64,9 +64,9 @@ class sdf::Link::Implementation
   public: std::vector<ParticleEmitter> emitters;
 
   /// \brief The inertial information for this link.
-  public: ignition::math::Inertiald inertial {{1.0,
-            ignition::math::Vector3d::One, ignition::math::Vector3d::Zero},
-            ignition::math::Pose3d::Zero};
+  public: gz::math::Inertiald inertial {{1.0,
+            gz::math::Vector3d::One, gz::math::Vector3d::Zero},
+            gz::math::Pose3d::Zero};
 
   /// \brief The SDF element pointer used during load.
   public: sdf::ElementPtr sdf;
@@ -80,7 +80,7 @@ class sdf::Link::Implementation
 
 /////////////////////////////////////////////////
 Link::Link()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -145,9 +145,9 @@ Errors Link::Load(ElementPtr _sdf)
   errors.insert(errors.end(), emitterLoadErrors.begin(),
       emitterLoadErrors.end());
 
-  ignition::math::Vector3d xxyyzz = ignition::math::Vector3d::One;
-  ignition::math::Vector3d xyxzyz = ignition::math::Vector3d::Zero;
-  ignition::math::Pose3d inertiaPose;
+  gz::math::Vector3d xxyyzz = gz::math::Vector3d::One;
+  gz::math::Vector3d xyxzyz = gz::math::Vector3d::Zero;
+  gz::math::Pose3d inertiaPose;
   std::string inertiaFrame = "";
   double mass = 1.0;
 
@@ -175,7 +175,7 @@ Errors Link::Load(ElementPtr _sdf)
     }
   }
   if (!this->dataPtr->inertial.SetMassMatrix(
-      ignition::math::MassMatrix3d(mass, xxyyzz, xyxzyz)))
+      gz::math::MassMatrix3d(mass, xxyyzz, xyxzyz)))
   {
     errors.push_back({ErrorCode::LINK_INERTIA_INVALID,
                      "A link named " +
@@ -409,20 +409,35 @@ ParticleEmitter *Link::ParticleEmitterByName(const std::string &_name)
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Inertiald &Link::Inertial() const
+const gz::math::Inertiald &Link::Inertial() const
 {
   return this->dataPtr->inertial;
 }
 
 /////////////////////////////////////////////////
-bool Link::SetInertial(const ignition::math::Inertiald &_inertial)
+bool Link::SetInertial(const gz::math::Inertiald &_inertial)
 {
   this->dataPtr->inertial = _inertial;
   return _inertial.MassMatrix().IsValid();
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Pose3d &Link::RawPose() const
+Errors Link::ResolveInertial(
+  gz::math::Inertiald &_inertial,
+  const std::string &_resolveTo) const
+{
+  gz::math::Pose3d linkPose;
+  auto errors = this->SemanticPose().Resolve(linkPose, _resolveTo);
+  if (errors.empty())
+  {
+    _inertial = this->dataPtr->inertial;
+    _inertial.SetPose(linkPose * _inertial.Pose());
+  }
+  return errors;
+}
+
+/////////////////////////////////////////////////
+const gz::math::Pose3d &Link::RawPose() const
 {
   return this->dataPtr->pose;
 }
@@ -434,7 +449,7 @@ const std::string &Link::PoseRelativeTo() const
 }
 
 /////////////////////////////////////////////////
-void Link::SetRawPose(const ignition::math::Pose3d &_pose)
+void Link::SetRawPose(const gz::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -659,13 +674,13 @@ sdf::ElementPtr Link::ToElement() const
     poseElem->GetAttribute("relative_to")->Set<std::string>(
         this->dataPtr->poseRelativeTo);
   }
-  poseElem->Set<ignition::math::Pose3d>(this->RawPose());
+  poseElem->Set<gz::math::Pose3d>(this->RawPose());
 
   // inertial
   sdf::ElementPtr inertialElem = elem->GetElement("inertial");
   inertialElem->GetElement("pose")->Set(
       this->dataPtr->inertial.Pose());
-  const ignition::math::MassMatrix3d &massMatrix =
+  const gz::math::MassMatrix3d &massMatrix =
     this->dataPtr->inertial.MassMatrix();
   inertialElem->GetElement("mass")->Set<double>(massMatrix.Mass());
   sdf::ElementPtr inertiaElem = inertialElem->GetElement("inertia");
