@@ -16,9 +16,9 @@
 */
 
 #include <gtest/gtest.h>
-#include <ignition/math/Inertial.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/math/Vector3.hh>
+#include <gz/math/Inertial.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/math/Vector3.hh>
 #include "sdf/Collision.hh"
 #include "sdf/Light.hh"
 #include "sdf/Link.hh"
@@ -67,19 +67,19 @@ TEST(DOMLink, Construction)
   EXPECT_FALSE(link.SensorNameExists(""));
   EXPECT_FALSE(link.SensorNameExists("default"));
 
-  EXPECT_EQ(ignition::math::Pose3d::Zero, link.RawPose());
+  EXPECT_EQ(gz::math::Pose3d::Zero, link.RawPose());
   EXPECT_TRUE(link.PoseRelativeTo().empty());
   {
     auto semanticPose = link.SemanticPose();
-    EXPECT_EQ(ignition::math::Pose3d::Zero, semanticPose.RawPose());
+    EXPECT_EQ(gz::math::Pose3d::Zero, semanticPose.RawPose());
     EXPECT_TRUE(semanticPose.RelativeTo().empty());
-    ignition::math::Pose3d pose;
+    gz::math::Pose3d pose;
     // expect errors when trying to resolve pose
     EXPECT_FALSE(semanticPose.Resolve(pose).empty());
   }
 
   link.SetRawPose({10, 20, 30, 0, IGN_PI, 0});
-  EXPECT_EQ(ignition::math::Pose3d(10, 20, 30, 0, IGN_PI, 0), link.RawPose());
+  EXPECT_EQ(gz::math::Pose3d(10, 20, 30, 0, IGN_PI, 0), link.RawPose());
 
   link.SetPoseRelativeTo("model");
   EXPECT_EQ("model", link.PoseRelativeTo());
@@ -87,13 +87,13 @@ TEST(DOMLink, Construction)
     auto semanticPose = link.SemanticPose();
     EXPECT_EQ(link.RawPose(), semanticPose.RawPose());
     EXPECT_EQ("model", semanticPose.RelativeTo());
-    ignition::math::Pose3d pose;
+    gz::math::Pose3d pose;
     // expect errors when trying to resolve pose
     EXPECT_FALSE(semanticPose.Resolve(pose).empty());
   }
 
   // Get the default inertial
-  const ignition::math::Inertiald inertial = link.Inertial();
+  const gz::math::Inertiald inertial = link.Inertial();
   EXPECT_DOUBLE_EQ(1.0, inertial.MassMatrix().Mass());
   EXPECT_DOUBLE_EQ(1.0, inertial.MassMatrix().DiagonalMoments().X());
   EXPECT_DOUBLE_EQ(1.0, inertial.MassMatrix().DiagonalMoments().Y());
@@ -109,11 +109,11 @@ TEST(DOMLink, Construction)
   EXPECT_FALSE(link.CollisionNameExists(""));
   EXPECT_FALSE(link.CollisionNameExists("default"));
 
-  ignition::math::Inertiald inertial2 {
+  gz::math::Inertiald inertial2 {
     {2.3,
-      ignition::math::Vector3d(1.4, 2.3, 3.2),
-      ignition::math::Vector3d(0.1, 0.2, 0.3)},
-      ignition::math::Pose3d(1, 2, 3, 0, 0, 0)};
+      gz::math::Vector3d(1.4, 2.3, 3.2),
+      gz::math::Vector3d(0.1, 0.2, 0.3)},
+      gz::math::Pose3d(1, 2, 3, 0, 0, 0)};
 
   EXPECT_TRUE(link.SetInertial(inertial2));
 
@@ -195,10 +195,10 @@ TEST(DOMLink, InvalidInertia)
   EXPECT_EQ(nullptr, link.Element());
   EXPECT_TRUE(link.Name().empty());
 
-  ignition::math::Inertiald invalidInertial {
-    {2.3, ignition::math::Vector3d(0.1, 0.2, 0.3),
-      ignition::math::Vector3d(1.2, 2.3, 3.4)},
-      ignition::math::Pose3d(1, 2, 3, 0, 0, 0)};
+  gz::math::Inertiald invalidInertial {
+    {2.3, gz::math::Vector3d(0.1, 0.2, 0.3),
+      gz::math::Vector3d(1.2, 2.3, 3.4)},
+      gz::math::Pose3d(1, 2, 3, 0, 0, 0)};
 
   EXPECT_FALSE(link.SetInertial(invalidInertial));
 
@@ -310,13 +310,13 @@ TEST(DOMLink, ToElement)
   sdf::Link link;
   link.SetName("my-name");
 
-  ignition::math::Inertiald inertial {
+  gz::math::Inertiald inertial {
     {2.3,
-      ignition::math::Vector3d(1.4, 2.3, 3.2),
-      ignition::math::Vector3d(0.1, 0.2, 0.3)},
-      ignition::math::Pose3d(1, 2, 3, 0, 0, 0)};
+      gz::math::Vector3d(1.4, 2.3, 3.2),
+      gz::math::Vector3d(0.1, 0.2, 0.3)},
+      gz::math::Pose3d(1, 2, 3, 0, 0, 0)};
   EXPECT_TRUE(link.SetInertial(inertial));
-  link.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0.1, 0.2, 0.3));
+  link.SetRawPose(gz::math::Pose3d(1, 2, 3, 0.1, 0.2, 0.3));
   link.SetEnableWind(true);
 
   for (int j = 0; j <= 1; ++j)
