@@ -17,6 +17,7 @@
 
 #include <algorithm>
 #include "sdf/Noise.hh"
+#include "sdf/parser.hh"
 #include "sdf/Types.hh"
 
 using namespace sdf;
@@ -56,7 +57,7 @@ class sdf::Noise::Implementation
 
 //////////////////////////////////////////////////
 Noise::Noise()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -238,13 +239,50 @@ bool Noise::operator!=(const Noise &_noise) const
 bool Noise::operator==(const Noise &_noise) const
 {
   return this->dataPtr->type == _noise.Type() &&
-    ignition::math::equal(this->dataPtr->mean, _noise.Mean()) &&
-    ignition::math::equal(this->dataPtr->stdDev, _noise.StdDev()) &&
-    ignition::math::equal(this->dataPtr->biasMean, _noise.BiasMean()) &&
-    ignition::math::equal(this->dataPtr->biasStdDev, _noise.BiasStdDev()) &&
-    ignition::math::equal(this->dataPtr->precision, _noise.Precision()) &&
-    ignition::math::equal(this->dataPtr->dynamicBiasStdDev,
+    gz::math::equal(this->dataPtr->mean, _noise.Mean()) &&
+    gz::math::equal(this->dataPtr->stdDev, _noise.StdDev()) &&
+    gz::math::equal(this->dataPtr->biasMean, _noise.BiasMean()) &&
+    gz::math::equal(this->dataPtr->biasStdDev, _noise.BiasStdDev()) &&
+    gz::math::equal(this->dataPtr->precision, _noise.Precision()) &&
+    gz::math::equal(this->dataPtr->dynamicBiasStdDev,
                           _noise.DynamicBiasStdDev()) &&
-    ignition::math::equal(this->dataPtr->dynamicBiasCorrelationTime,
+    gz::math::equal(this->dataPtr->dynamicBiasCorrelationTime,
                           _noise.DynamicBiasCorrelationTime());
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr Noise::ToElement() const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("noise.sdf", elem);
+
+  std::string noiseType;
+  switch (this->Type())
+  {
+    case sdf::NoiseType::NONE:
+      noiseType = "none";
+      break;
+    case sdf::NoiseType::GAUSSIAN:
+      noiseType = "gaussian";
+      break;
+    case sdf::NoiseType::GAUSSIAN_QUANTIZED:
+      noiseType = "gaussian_quantized";
+      break;
+    default:
+      noiseType = "none";
+  }
+  elem->GetAttribute("type")->Set<std::string>(noiseType);
+  elem->GetElement("mean")->Set<double>(this->Mean());
+  elem->GetElement("stddev")->Set<double>(this->StdDev());
+
+  // camera and lidar <noise> does not have the sdf params below
+  elem->GetElement("bias_mean")->Set<double>(this->BiasMean());
+  elem->GetElement("bias_stddev")->Set<double>(this->BiasStdDev());
+  elem->GetElement("dynamic_bias_stddev")->Set<double>(
+    this->DynamicBiasStdDev());
+  elem->GetElement("dynamic_bias_correlation_time")->Set<double>(
+      this->DynamicBiasCorrelationTime());
+  elem->GetElement("precision")->Set<double>(this->Precision());
+
+  return elem;
+}
