@@ -28,7 +28,7 @@ class sdf::Polyline::Implementation
   public: double height{1.0};
 
   /// \brief 2D points.
-  public: std::vector<ignition::math::Vector2d> points;
+  public: std::vector<gz::math::Vector2d> points;
 
   /// \brief The SDF element pointer used during load.
   public: sdf::ElementPtr sdf;
@@ -36,7 +36,7 @@ class sdf::Polyline::Implementation
 
 /////////////////////////////////////////////////
 Polyline::Polyline()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -87,7 +87,7 @@ Errors Polyline::Load(ElementPtr _sdf)
        pointElem != nullptr;
        pointElem = pointElem->GetNextElement("point"))
   {
-    this->dataPtr->points.push_back(pointElem->Get<ignition::math::Vector2d>());
+    this->dataPtr->points.push_back(pointElem->Get<gz::math::Vector2d>());
   }
 
   return errors;
@@ -112,7 +112,7 @@ uint64_t Polyline::PointCount() const
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Vector2d *Polyline::PointByIndex(uint64_t _index) const
+const gz::math::Vector2d *Polyline::PointByIndex(uint64_t _index) const
 {
   if (_index < this->dataPtr->points.size())
     return &this->dataPtr->points[_index];
@@ -120,7 +120,7 @@ const ignition::math::Vector2d *Polyline::PointByIndex(uint64_t _index) const
 }
 
 /////////////////////////////////////////////////
-ignition::math::Vector2d *Polyline::PointByIndex(uint64_t _index)
+gz::math::Vector2d *Polyline::PointByIndex(uint64_t _index)
 {
   if (_index < this->dataPtr->points.size())
     return &this->dataPtr->points[_index];
@@ -128,7 +128,7 @@ ignition::math::Vector2d *Polyline::PointByIndex(uint64_t _index)
 }
 
 /////////////////////////////////////////////////
-bool Polyline::AddPoint(const ignition::math::Vector2d &_point)
+bool Polyline::AddPoint(const gz::math::Vector2d &_point)
 {
   if (this->dataPtr->points.size() == this->dataPtr->points.max_size())
   {
@@ -145,7 +145,7 @@ void Polyline::ClearPoints()
 }
 
 /////////////////////////////////////////////////
-const std::vector<ignition::math::Vector2d> &Polyline::Points() const
+const std::vector<gz::math::Vector2d> &Polyline::Points() const
 {
   return this->dataPtr->points;
 }
@@ -168,7 +168,7 @@ sdf::ElementPtr Polyline::ToElement() const
   for (auto &point : this->dataPtr->points)
   {
     auto pointElem = elem->AddElement("point");
-    pointElem->Set<ignition::math::Vector2d>(point);
+    pointElem->Set<gz::math::Vector2d>(point);
   }
 
   return elem;
