@@ -22,8 +22,8 @@
 TEST(DOMScene, Construction)
 {
   sdf::Scene scene;
-  EXPECT_EQ(ignition::math::Color(0.4f, 0.4f, 0.4f), scene.Ambient());
-  EXPECT_EQ(ignition::math::Color(0.7f, 0.7f, 0.7f), scene.Background());
+  EXPECT_EQ(gz::math::Color(0.4f, 0.4f, 0.4f), scene.Ambient());
+  EXPECT_EQ(gz::math::Color(0.7f, 0.7f, 0.7f), scene.Background());
   EXPECT_TRUE(scene.Grid());
   EXPECT_TRUE(scene.Shadows());
   EXPECT_TRUE(scene.OriginVisual());
@@ -37,8 +37,8 @@ TEST(DOMScene, CopyConstruction)
 
   sdf::Scene scene;
   scene.Load(sdf);
-  scene.SetAmbient(ignition::math::Color::Blue);
-  scene.SetBackground(ignition::math::Color::Red);
+  scene.SetAmbient(gz::math::Color::Blue);
+  scene.SetBackground(gz::math::Color::Red);
   scene.SetGrid(false);
   scene.SetShadows(false);
   scene.SetOriginVisual(false);
@@ -46,8 +46,8 @@ TEST(DOMScene, CopyConstruction)
   scene.SetSky(sky);
 
   sdf::Scene scene2(scene);
-  EXPECT_EQ(ignition::math::Color::Blue, scene2.Ambient());
-  EXPECT_EQ(ignition::math::Color::Red, scene2.Background());
+  EXPECT_EQ(gz::math::Color::Blue, scene2.Ambient());
+  EXPECT_EQ(gz::math::Color::Red, scene2.Background());
   EXPECT_FALSE(scene2.Grid());
   EXPECT_FALSE(scene2.Shadows());
   EXPECT_FALSE(scene2.OriginVisual());
@@ -61,8 +61,8 @@ TEST(DOMScene, CopyConstruction)
 TEST(DOMScene, MoveConstruction)
 {
   sdf::Scene scene;
-  scene.SetAmbient(ignition::math::Color::Blue);
-  scene.SetBackground(ignition::math::Color::Red);
+  scene.SetAmbient(gz::math::Color::Blue);
+  scene.SetBackground(gz::math::Color::Red);
   scene.SetGrid(false);
   scene.SetShadows(false);
   scene.SetOriginVisual(false);
@@ -70,8 +70,8 @@ TEST(DOMScene, MoveConstruction)
   scene.SetSky(sky);
 
   sdf::Scene scene2(std::move(scene));
-  EXPECT_EQ(ignition::math::Color::Blue, scene2.Ambient());
-  EXPECT_EQ(ignition::math::Color::Red, scene2.Background());
+  EXPECT_EQ(gz::math::Color::Blue, scene2.Ambient());
+  EXPECT_EQ(gz::math::Color::Red, scene2.Background());
   EXPECT_FALSE(scene2.Grid());
   EXPECT_FALSE(scene2.Shadows());
   EXPECT_FALSE(scene2.OriginVisual());
@@ -82,8 +82,8 @@ TEST(DOMScene, MoveConstruction)
 TEST(DOMScene, MoveAssignmentOperator)
 {
   sdf::Scene scene;
-  scene.SetAmbient(ignition::math::Color::Green);
-  scene.SetBackground(ignition::math::Color::White);
+  scene.SetAmbient(gz::math::Color::Green);
+  scene.SetBackground(gz::math::Color::White);
   scene.SetGrid(false);
   scene.SetShadows(false);
   scene.SetOriginVisual(false);
@@ -92,8 +92,8 @@ TEST(DOMScene, MoveAssignmentOperator)
 
   sdf::Scene scene2;
   scene2 = std::move(scene);
-  EXPECT_EQ(ignition::math::Color::Green, scene2.Ambient());
-  EXPECT_EQ(ignition::math::Color::White, scene2.Background());
+  EXPECT_EQ(gz::math::Color::Green, scene2.Ambient());
+  EXPECT_EQ(gz::math::Color::White, scene2.Background());
   EXPECT_FALSE(scene2.Grid());
   EXPECT_FALSE(scene2.Shadows());
   EXPECT_FALSE(scene2.OriginVisual());
@@ -104,8 +104,8 @@ TEST(DOMScene, MoveAssignmentOperator)
 TEST(DOMScene, AssignmentOperator)
 {
   sdf::Scene scene;
-  scene.SetAmbient(ignition::math::Color::Red);
-  scene.SetBackground(ignition::math::Color(0.2f, 0.3f, 0.4f));
+  scene.SetAmbient(gz::math::Color::Red);
+  scene.SetBackground(gz::math::Color(0.2f, 0.3f, 0.4f));
   scene.SetGrid(false);
   scene.SetShadows(false);
   scene.SetOriginVisual(false);
@@ -114,8 +114,8 @@ TEST(DOMScene, AssignmentOperator)
 
   sdf::Scene scene2;
   scene2 = scene;
-  EXPECT_EQ(ignition::math::Color::Red, scene2.Ambient());
-  EXPECT_EQ(ignition::math::Color(0.2f, 0.3f, 0.4f), scene2.Background());
+  EXPECT_EQ(gz::math::Color::Red, scene2.Ambient());
+  EXPECT_EQ(gz::math::Color(0.2f, 0.3f, 0.4f), scene2.Background());
   EXPECT_FALSE(scene2.Grid());
   EXPECT_FALSE(scene2.Shadows());
   EXPECT_FALSE(scene2.OriginVisual());
@@ -126,10 +126,10 @@ TEST(DOMScene, AssignmentOperator)
 TEST(DOMScene, CopyAssignmentAfterMove)
 {
   sdf::Scene scene1;
-  scene1.SetAmbient(ignition::math::Color::Red);
+  scene1.SetAmbient(gz::math::Color::Red);
 
   sdf::Scene scene2;
-  scene2.SetAmbient(ignition::math::Color::Green);
+  scene2.SetAmbient(gz::math::Color::Green);
 
   // This is similar to what std::swap does except it uses std::move for each
   // assignment
@@ -137,19 +137,19 @@ TEST(DOMScene, CopyAssignmentAfterMove)
   scene1 = scene2;
   scene2 = tmp;
 
-  EXPECT_EQ(ignition::math::Color::Green, scene1.Ambient());
-  EXPECT_EQ(ignition::math::Color::Red, scene2.Ambient());
+  EXPECT_EQ(gz::math::Color::Green, scene1.Ambient());
+  EXPECT_EQ(gz::math::Color::Red, scene2.Ambient());
 }
 
 /////////////////////////////////////////////////
 TEST(DOMScene, Set)
 {
   sdf::Scene scene;
-  scene.SetAmbient(ignition::math::Color(0.1f, 0.2f, 0.3f));
-  EXPECT_EQ(ignition::math::Color(0.1f, 0.2f, 0.3f), scene.Ambient());
+  scene.SetAmbient(gz::math::Color(0.1f, 0.2f, 0.3f));
+  EXPECT_EQ(gz::math::Color(0.1f, 0.2f, 0.3f), scene.Ambient());
 
-  scene.SetBackground(ignition::math::Color(0.1f, 0.2f, 0.3f));
-  EXPECT_EQ(ignition::math::Color(0.1f, 0.2f, 0.3f), scene.Ambient());
+  scene.SetBackground(gz::math::Color(0.1f, 0.2f, 0.3f));
+  EXPECT_EQ(gz::math::Color(0.1f, 0.2f, 0.3f), scene.Ambient());
 
   scene.SetGrid(true);
   EXPECT_TRUE(scene.Grid());
@@ -176,8 +176,8 @@ TEST(DOMScene, ToElement)
 {
   sdf::Scene scene;
 
-  scene.SetAmbient(ignition::math::Color(0.1f, 0.2f, 0.3f, 1.0f));
-  scene.SetBackground(ignition::math::Color(0.2f, 0.3f, 0.4f, 1.0f));
+  scene.SetAmbient(gz::math::Color(0.1f, 0.2f, 0.3f, 1.0f));
+  scene.SetBackground(gz::math::Color(0.2f, 0.3f, 0.4f, 1.0f));
   scene.SetGrid(true);
   scene.SetOriginVisual(true);
   scene.SetShadows(true);
