@@ -16,7 +16,7 @@
 */
 #include <memory>
 #include <string>
-#include <ignition/math/Pose3.hh>
+#include <gz/math/Pose3.hh>
 #include "FrameSemantics.hh"
 #include "ScopedGraph.hh"
 #include "sdf/Error.hh"
@@ -40,7 +40,7 @@ class sdf::Visual::Implementation
   public: float transparency  = 0.0;
 
   /// \brief Pose of the visual object
-  public: ignition::math::Pose3d pose = ignition::math::Pose3d::Zero;
+  public: gz::math::Pose3d pose = gz::math::Pose3d::Zero;
 
   /// \brief Frame of the pose.
   public: std::string poseRelativeTo = "";
@@ -75,7 +75,7 @@ class sdf::Visual::Implementation
 
 /////////////////////////////////////////////////
 Visual::Visual()
-  : dataPtr(ignition::utils::MakeImpl<Implementation>())
+  : dataPtr(gz::utils::MakeImpl<Implementation>())
 {
 }
 
@@ -197,7 +197,7 @@ void Visual::SetTransparency(float _transparency)
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Pose3d &Visual::RawPose() const
+const gz::math::Pose3d &Visual::RawPose() const
 {
   return this->dataPtr->pose;
 }
@@ -209,7 +209,7 @@ const std::string &Visual::PoseRelativeTo() const
 }
 
 /////////////////////////////////////////////////
-void Visual::SetRawPose(const ignition::math::Pose3d &_pose)
+void Visual::SetRawPose(const gz::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -325,7 +325,7 @@ sdf::ElementPtr Visual::ToElement() const
     poseElem->GetAttribute("relative_to")->Set<std::string>(
         this->dataPtr->poseRelativeTo);
   }
-  poseElem->Set<ignition::math::Pose3d>(this->RawPose());
+  poseElem->Set<gz::math::Pose3d>(this->RawPose());
 
   // Set the geometry
   elem->InsertElement(this->dataPtr->geom.ToElement(), true);
