@@ -16,16 +16,19 @@
 */
 
 #include <gtest/gtest.h>
+#include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string>
 
-#include <ignition/utils/ExtraTestMacros.hh>
+#include <gz/utils/ExtraTestMacros.hh>
 
+#include "sdf/Filesystem.hh"
 #include "sdf/parser.hh"
 #include "sdf/SDFImpl.hh"
 #include "sdf/sdf_config.h"
 #include "test_config.h"
+#include "test_utils.hh"
 
 #ifdef _WIN32
   #define popen  _popen
@@ -948,12 +951,6 @@ TEST(print, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   }
 }
 
-//////////////////////////////////////////////////
-static bool contains(const std::string &_a, const std::string &_b)
-{
-  return _a.find(_b) != std::string::npos;
-}
-
 /////////////////////////////////////////////////
 TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
 {
@@ -964,14 +961,14 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true'>1 2 3   30.009 44.991 -60.009</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -980,7 +977,7 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -989,7 +986,7 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -998,7 +995,7 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1007,7 +1004,7 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1016,7 +1013,7 @@ TEST(print_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1031,14 +1028,14 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose>1 2 3 0.523756 0.785241 -1.04735</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.0087</pose>");
 
@@ -1047,7 +1044,7 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1056,7 +1053,7 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1065,7 +1062,7 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1074,7 +1071,7 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.0087</pose>");
 
@@ -1083,7 +1080,7 @@ TEST(print_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1098,7 +1095,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose rotation_format='quat_xyzw'>"
                "1 2 3   0.391948 0.200425 -0.532046 0.723279</pose>");
 
@@ -1106,7 +1103,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1115,7 +1112,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1124,7 +1121,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1133,7 +1130,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1142,7 +1139,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1151,7 +1148,7 @@ TEST(print_rotations_in_quaternions, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1169,14 +1166,14 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true'>1 2 3   30.009 44.991 -60.009</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1185,7 +1182,7 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1194,7 +1191,7 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1203,7 +1200,7 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1212,7 +1209,7 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1221,7 +1218,7 @@ TEST(print_includes_rotations_in_degrees, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1239,14 +1236,14 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose>1 2 3 0.523756 0.785241 -1.04735</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.0087</pose>");
 
@@ -1255,7 +1252,7 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1264,7 +1261,7 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1273,7 +1270,7 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1282,7 +1279,7 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.0087</pose>");
 
@@ -1291,7 +1288,7 @@ TEST(print_includes_rotations_in_radians, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1310,7 +1307,7 @@ TEST(print_includes_rotations_in_quaternions,
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose rotation_format='quat_xyzw'>"
                "1 2 3   0.391948 0.200425 -0.532046 0.723279</pose>");
 
@@ -1318,7 +1315,7 @@ TEST(print_includes_rotations_in_quaternions,
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1327,7 +1324,7 @@ TEST(print_includes_rotations_in_quaternions,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1336,7 +1333,7 @@ TEST(print_includes_rotations_in_quaternions,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1345,7 +1342,7 @@ TEST(print_includes_rotations_in_quaternions,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1354,7 +1351,7 @@ TEST(print_includes_rotations_in_quaternions,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1363,7 +1360,7 @@ TEST(print_includes_rotations_in_quaternions,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1382,14 +1379,14 @@ TEST(print_rotations_in_unnormalized_degrees,
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true'>1 2 3   30.009 44.991 -60.009</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1398,7 +1395,7 @@ TEST(print_rotations_in_unnormalized_degrees,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1407,7 +1404,7 @@ TEST(print_rotations_in_unnormalized_degrees,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.991 -60</pose>");
 
@@ -1416,7 +1413,7 @@ TEST(print_rotations_in_unnormalized_degrees,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60</pose>");
 
@@ -1425,7 +1422,7 @@ TEST(print_rotations_in_unnormalized_degrees,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.991 -60.009</pose>");
 
@@ -1434,7 +1431,7 @@ TEST(print_rotations_in_unnormalized_degrees,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1450,14 +1447,14 @@ TEST(print_rotations_in_unnormalized_radians,
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose>1 2 3 -5.75943 -11.78112 5.23583</pose>");
 
   // Printing with in_degrees
   output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.9915 -60.009</pose>");
 
@@ -1466,7 +1463,7 @@ TEST(print_rotations_in_unnormalized_radians,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1475,7 +1472,7 @@ TEST(print_rotations_in_unnormalized_radians,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 2 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 44.9915 -60</pose>");
 
@@ -1484,7 +1481,7 @@ TEST(print_rotations_in_unnormalized_radians,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 20 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.9915 -60</pose>");
 
@@ -1493,7 +1490,7 @@ TEST(print_rotations_in_unnormalized_radians,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.008 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.9915 -60.009</pose>");
 
@@ -1502,7 +1499,7 @@ TEST(print_rotations_in_unnormalized_radians,
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       "--snap-tolerance 0.01 " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1517,7 +1514,7 @@ TEST(shuffled_cmd_flags, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   std::string output = custom_exec_str(
       IgnCommand() + " sdf -p " + path + " --degrees " + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.9915 -60.009</pose>");
 
@@ -1525,7 +1522,7 @@ TEST(shuffled_cmd_flags, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   output = custom_exec_str(
       IgnCommand() + " sdf --degrees -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30.009 44.9915 -60.009</pose>");
 
@@ -1534,7 +1531,7 @@ TEST(shuffled_cmd_flags, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
       IgnCommand() + " sdf -p " + path + " --snap-to-degrees 5 " +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1542,7 +1539,7 @@ TEST(shuffled_cmd_flags, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   output = custom_exec_str(
       IgnCommand() + " sdf -p --snap-to-degrees 5 " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 
@@ -1550,7 +1547,7 @@ TEST(shuffled_cmd_flags, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   output = custom_exec_str(
       IgnCommand() + " sdf --snap-to-degrees 5 -p " + path + SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 45 -60</pose>");
 }
@@ -1568,7 +1565,7 @@ TEST(print_snap_to_degrees_tolerance_too_high,
       " --snap-to-degrees 5 " + " --snap-tolerance 4" +
       SdfVersion());
   ASSERT_FALSE(output.empty());
-  EXPECT_PRED2(contains, output,
+  EXPECT_PRED2(sdf::testing::contains, output,
                "<pose degrees='true' rotation_format='euler_rpy'>"
                "1 2 3   30 50 60</pose>");
 }
@@ -1878,6 +1875,38 @@ TEST(inertial_stats, IGN_UTILS_TEST_DISABLED_ON_WIN32(SDF))
   }
 }
 
+//////////////////////////////////////////////////
+/// \brief Check help message and bash completion script for consistent flags
+TEST(HelpVsCompletionFlags, SDF)
+{
+  // Flags in help message
+  std::string helpOutput = custom_exec_str(IgnCommand() + " sdf --help");
+
+  // Call the output function in the bash completion script
+  std::string scriptPath = PROJECT_SOURCE_PATH;
+  scriptPath = sdf::filesystem::append(scriptPath, "src", "cmd",
+      "sdf.bash_completion.sh");
+
+  // Equivalent to:
+  // sh -c "bash -c \". /path/to/sdf.bash_completion.sh; _gz_sdf_flags\""
+  std::string cmd = "bash -c \". " + scriptPath +
+    "; _gz_sdf_flags\"";
+  std::string scriptOutput = custom_exec_str(cmd);
+
+  // Tokenize script output
+  std::istringstream iss(scriptOutput);
+  std::vector<std::string> flags((std::istream_iterator<std::string>(iss)),
+    std::istream_iterator<std::string>());
+
+  EXPECT_GT(flags.size(), 0u);
+
+  // Match each flag in script output with help message
+  for (const auto &flag : flags)
+  {
+    EXPECT_NE(std::string::npos, helpOutput.find(flag)) << helpOutput;
+  }
+}
+
 /////////////////////////////////////////////////
 /// Main
 int main(int argc, char **argv)
