@@ -80,17 +80,12 @@ TEST(DOMJointAxis, Complete)
   const sdf::JointAxis *axis2 = joint->Axis(1);
   ASSERT_NE(nullptr, axis2);
 
-  EXPECT_EQ(ignition::math::Vector3d::UnitZ, axis->Xyz());
-  EXPECT_EQ(ignition::math::Vector3d::UnitY, axis2->Xyz());
+  EXPECT_EQ(gz::math::Vector3d::UnitZ, axis->Xyz());
+  EXPECT_EQ(gz::math::Vector3d::UnitY, axis2->Xyz());
 
   EXPECT_EQ("__model__", axis->XyzExpressedIn());
   EXPECT_TRUE(axis2->XyzExpressedIn().empty());
 
-  SDF_SUPPRESS_DEPRECATED_BEGIN
-  EXPECT_DOUBLE_EQ(0.5, axis->InitialPosition());
-  EXPECT_DOUBLE_EQ(1.5, axis2->InitialPosition());
-  SDF_SUPPRESS_DEPRECATED_END
-
   EXPECT_DOUBLE_EQ(-0.5, axis->Lower());
   EXPECT_DOUBLE_EQ(0.5, axis->Upper());
   EXPECT_DOUBLE_EQ(-1.0, axis2->Lower());
@@ -126,9 +121,9 @@ TEST(DOMJointAxis, XyzExpressedIn)
   sdf::Errors errors = root.Load(testFile);
   EXPECT_TRUE(errors.empty());
 
-  using Pose = ignition::math::Pose3d;
-  using Quaternion = ignition::math::Quaterniond;
-  using Vector3 = ignition::math::Vector3d;
+  using Pose = gz::math::Pose3d;
+  using Quaternion = gz::math::Quaterniond;
+  using Vector3 = gz::math::Vector3d;
 
   // Get the first model
   const sdf::Model *model = root.Model();
@@ -304,7 +299,7 @@ TEST(DOMJointAxis, XyzNormalization)
       errors[0].Message().find("The norm of the xyz vector cannot be zero") !=
       std::string::npos);
 
-  using ignition::math::Vector3d;
+  using gz::math::Vector3d;
 
   // Get the first model
   const sdf::Model *model = root.Model();
