@@ -13,37 +13,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
-*/
+ */
+
+#include <string>
 
 #include <gtest/gtest.h>
-#include <map>
-#include <boost/filesystem.hpp>
+
 #include "sdf/sdf.hh"
 
 #include "test_config.h"
 
-const std::string SDF_TEST_FILE = std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/urdf_joint_parameters.urdf";
-
 /////////////////////////////////////////////////
 TEST(SDFParser, JointAxisParameters)
 {
-  char *pathCStr = getenv("SDF_PATH");
-  boost::filesystem::path path = PROJECT_SOURCE_PATH;
-  path = path / "sdf" / SDF_VERSION;
-  setenv("SDF_PATH", path.string().c_str(), 1);
+  const std::string sdfTestFile =
+      sdf::testing::TestFile("integration", "urdf_joint_parameters.urdf");
 
   sdf::SDFPtr robot(new sdf::SDF());
   sdf::init(robot);
-  ASSERT_TRUE(sdf::readFile(SDF_TEST_FILE, robot));
-  if (pathCStr)
-  {
-    setenv("SDF_PATH", pathCStr, 1);
-  }
-  else
-  {
-    unsetenv("SDF_PATH");
-  }
+  ASSERT_TRUE(sdf::readFile(sdfTestFile, robot));
 
   sdf::ElementPtr model = robot->Root()->GetElement("model");
 
@@ -77,6 +65,31 @@ TEST(SDFParser, JointAxisParameters)
     ASSERT_TRUE(dynamics->HasElement("friction"));
     EXPECT_DOUBLE_EQ(value, dynamics->Get<double>("damping"));
     EXPECT_DOUBLE_EQ(value, dynamics->Get<double>("friction"));
+
+    EXPECT_TRUE(axis->HasElement("limit"));
+    sdf::ElementPtr limit = axis->GetElement("limit");
+    EXPECT_TRUE(limit->HasElement("effort"));
+    EXPECT_TRUE(limit->HasElement("velocity"));
+    EXPECT_DOUBLE_EQ(value, limit->Get<double>("effort"));
+    EXPECT_DOUBLE_EQ(value, limit->Get<double>("velocity"));
   }
   EXPECT_EQ(bitmask, 0x3u);
+
+  // check joint axis values
+  for (sdf::ElementPtr joint = model->GetElement("joint"); joint;
+       joint = joint->GetNextElement("joint"))
+  {
+    std::string jointName = joint->Get<std::string>("name");
+
+    gz::math::Vector3d xyz(1, 0, 0);
+    if (jointName == "joint12" || jointName == "joint23")
+    {
+      xyz.Set(0, 1, 0);
+    }
+
+    ASSERT_TRUE(joint->HasElement("axis"));
+    sdf::ElementPtr axis = joint->GetElement("axis");
+    EXPECT_EQ(xyz, axis->Get<gz::math::Vector3d>("xyz"));
+    EXPECT_FALSE(axis->Get<bool>("use_parent_model_frame"));
+  }
 }
