@@ -20,6 +20,7 @@
 
 #include "sdf/sdf.hh"
 #include "sdf/parser.hh"
+#include "sdf/ParserConfig.hh"
 #include "test_config.h"
 #include "test_utils.hh"
 
@@ -37,11 +38,13 @@ TEST(URDF2SDF, ValidBasicURDF)
       </link>
     </robot>)";
 
-  sdf::Root root;
-  sdf::Errors errors = root.LoadSdfString(urdfXml);
-  ASSERT_TRUE(errors.empty());
+  sdf::ParserConfig config;
 
-  const sdf::Model *model = root.ModelByIndex(0);
+  sdf::Root root;
+  sdf::Errors errors = root.LoadSdfString(urdfXml, config);
+  ASSERT_TRUE(errors.empty()) << errors;
+
+  const sdf::Model *model = root.Model();
   ASSERT_NE(nullptr, model);
   EXPECT_TRUE(model->LinkNameExists("link1"));
 }
@@ -72,11 +75,13 @@ TEST(URDF2SDF, ValidContinuousJointedURDF)
       </joint>
     </robot>)";
 
-  sdf::Root root;
-  sdf::Errors errors = root.LoadSdfString(urdfXml);
-  ASSERT_TRUE(errors.empty());
+  sdf::ParserConfig config;
 
-  const sdf::Model *model = root.ModelByIndex(0);
+  sdf::Root root;
+  sdf::Errors errors = root.LoadSdfString(urdfXml, config);
+  ASSERT_TRUE(errors.empty()) << errors;
+
+  const sdf::Model *model = root.Model();
   ASSERT_NE(nullptr, model);
   EXPECT_TRUE(model->LinkNameExists("link1"));
   EXPECT_TRUE(model->LinkNameExists("link2"));
@@ -143,10 +148,11 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedParentJoint)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
-    ASSERT_TRUE(errors.empty());
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
+    ASSERT_TRUE(errors.empty()) << errors;
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     const sdf::Link *link = model->LinkByName("link1");
     ASSERT_NE(nullptr, link);
@@ -230,10 +236,11 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedParentJoint)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
 
     // no sdf errors, however we expect warnings and ignored joints and links
-    ASSERT_TRUE(errors.empty());
+    ASSERT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link2] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -252,7 +259,97 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedParentJoint)
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link2] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
+    ASSERT_NE(nullptr, model);
+    const sdf::Link *link = model->LinkByName("link1");
+    ASSERT_NE(nullptr, link);
+
+    // expect everything below joint1_2 to be ignored
+    EXPECT_FALSE(model->LinkNameExists("link2"));
+    EXPECT_FALSE(model->JointNameExists("joint1_2"));
+    EXPECT_FALSE(model->LinkNameExists("link3"));
+    EXPECT_FALSE(model->JointNameExists("joint2_3"));
+
+    // expect no visual or collision from link2 lumped into link1
+    EXPECT_FALSE(
+        link->VisualNameExists("link1_fixed_joint_lump__link2_visual"));
+    EXPECT_FALSE(
+        link->CollisionNameExists("link1_fixed_joint_lump__link2_collision"));
+  }
+
+  // Disabling lumping using ParserConfig::URDFPreserveFixedJoint, fails with
+  // warnings suggesting to set to false
+  {
+    // clear the contents of the buffer
+    buffer.str("");
+
+    std::string urdfXml = R"(
+      <robot name='test_robot'>
+        <link name='link1'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <link name='link2'> <!-- zero mass link -->
+          <visual>
+            <origin rpy="3 -0 0" xyz="0 0 0"/>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </visual>
+          <collision>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </collision>
+        </link>
+        <joint name='joint1_2' type='fixed'>
+          <parent link='link1' />
+          <child  link='link2' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+        <link name='link3'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <joint name='joint2_3' type='continuous'>
+          <parent link='link2' />
+          <child  link='link3' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+      </robot>)";
+
+    sdf::Root root;
+    sdf::ParserConfig config;
+    config.URDFSetPreserveFixedJoint(true);
+    sdf::Errors errors = root.LoadSdfString(urdfXml, config);
+
+    // no sdf errors, however we expect warnings and ignored joints and links
+    ASSERT_TRUE(errors.empty()) << errors;
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link2] has no <inertial> block defined. Please ensure this link "
+        "has a valid mass to prevent any missing links or joints in the "
+        "resulting SDF model");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "allowing joint lumping by removing any <disableFixedJointLumping> or "
+        "<preserveFixedJoint> gazebo tag on fixed parent joint[joint1_2], as "
+        "well as ensuring that ParserConfig::URDFPreserveFixedJoint is false, "
+        "could help resolve this warning");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "parent joint[joint1_2] ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "[1] child links ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "[1] child joints ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link2] is not modeled in sdf");
+
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     const sdf::Link *link = model->LinkByName("link1");
     ASSERT_NE(nullptr, link);
@@ -335,10 +432,11 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedChildJoint)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
 
     // lumping and reduction occurs, no warnings or errors should be present
-    ASSERT_TRUE(errors.empty());
+    ASSERT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link2] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -346,7 +444,7 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedChildJoint)
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link2] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("link1"));
 
@@ -425,11 +523,12 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedChildJoint)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
 
     // Everything beneath joint1_2 is ignored, no sdf errors, but warnings
     // expected with suggestion to remove gazebo tag
-    ASSERT_TRUE(errors.empty());
+    ASSERT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link2] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -448,7 +547,93 @@ TEST(URDF2SDF, ZeroMassIntermediateLinkWithFixedChildJoint)
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link2] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
+    ASSERT_NE(nullptr, model);
+    EXPECT_TRUE(model->LinkNameExists("link1"));
+    EXPECT_FALSE(model->LinkNameExists("link2"));
+    EXPECT_FALSE(model->FrameNameExists("link2"));
+    EXPECT_FALSE(model->JointNameExists("joint1_2"));
+    EXPECT_FALSE(model->FrameNameExists("joint1_2"));
+    EXPECT_FALSE(model->LinkNameExists("link3"));
+    EXPECT_FALSE(model->FrameNameExists("link3"));
+    EXPECT_FALSE(model->JointNameExists("joint2_3"));
+    EXPECT_FALSE(model->FrameNameExists("joint2_3"));
+  }
+
+  // Disabling lumping using ParserConfig::URDFPreserveFixedJoint, fails with
+  // warnings suggesting to set to false
+  {
+    // clear the contents of the buffer
+    buffer.str("");
+
+    std::string urdfXml = R"(
+      <robot name='test_robot'>
+        <link name='link1'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <link name='link2'> <!-- zero mass link -->
+          <visual>
+            <origin rpy="3 -0 0" xyz="0 0 0"/>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </visual>
+          <collision>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </collision>
+        </link>
+        <joint name='joint1_2' type='continuous'>
+          <parent link='link1' />
+          <child  link='link2' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+        <link name='link3'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <joint name='joint2_3' type='fixed'>
+          <parent link='link2' />
+          <child  link='link3' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+      </robot>)";
+
+    sdf::Root root;
+    sdf::ParserConfig config;
+    config.URDFSetPreserveFixedJoint(true);
+    sdf::Errors errors = root.LoadSdfString(urdfXml, config);
+
+    // Everything beneath joint1_2 is ignored, no sdf errors, but warnings
+    // expected with suggestion to remove gazebo tag
+    ASSERT_TRUE(errors.empty()) << errors;
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link2] has no <inertial> block defined. Please ensure this link "
+        "has a valid mass to prevent any missing links or joints in the "
+        "resulting SDF model");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "parent joint[joint1_2] ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "allowing joint lumping by removing any <disableFixedJointLumping> or "
+        "<preserveFixedJoint> gazebo tag on fixed child joint[joint2_3], as "
+        "well as ensuring that ParserConfig::URDFPreserveFixedJoint is false, "
+        "could help resolve this warning");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "[1] child joints ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "[1] child links ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link2] is not modeled in sdf");
+
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("link1"));
     EXPECT_FALSE(model->LinkNameExists("link2"));
@@ -525,10 +710,11 @@ TEST(URDFParser, ZeroMassLeafLink)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
 
     // lumping and reduction occurs, no warnings should be present
-    ASSERT_TRUE(errors.empty());
+    ASSERT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link3] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -536,7 +722,7 @@ TEST(URDFParser, ZeroMassLeafLink)
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link3] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("link1"));
 
@@ -618,11 +804,12 @@ TEST(URDFParser, ZeroMassLeafLink)
       </robot>)";
 
     sdf::Root root;
-    sdf::Errors errors = root.LoadSdfString(urdfXml);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.LoadSdfString(urdfXml, defaultConfig);
 
     // joint2_3 and link3 will be ignored, and warnings suggesting to remove
     // gazebo tags
-    ASSERT_TRUE(errors.empty());
+    ASSERT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link3] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -637,7 +824,101 @@ TEST(URDFParser, ZeroMassLeafLink)
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link3] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
+    ASSERT_NE(nullptr, model);
+    EXPECT_TRUE(model->LinkNameExists("link1"));
+
+    // link2
+    const sdf::Link *link = model->LinkByName("link2");
+    ASSERT_NE(nullptr, link);
+    EXPECT_TRUE(model->JointNameExists("joint1_2"));
+
+    // joint1_2
+    EXPECT_TRUE(model->JointNameExists("joint1_2"));
+
+    // link3 visual and collision not lumped into link2
+    EXPECT_FALSE(
+        link->VisualNameExists("link2_fixed_joint_lump__link3_visual"));
+    EXPECT_FALSE(
+        link->CollisionNameExists("link2_fixed_joint_lump__link3_collision"));
+
+    // joint2_3 and link3 ignored
+    EXPECT_FALSE(model->LinkNameExists("link3"));
+    EXPECT_FALSE(model->FrameNameExists("link3"));
+    EXPECT_FALSE(model->JointNameExists("joint2_3"));
+    EXPECT_FALSE(model->FrameNameExists("joint2_3"));
+  }
+
+  // ParserConfig::URDFSetPreserveFixedJoint set to true, expect link3 and
+  // joint2_3 to be ignored and warnings suggesting to remove gazebo tag
+  {
+    // clear the contents of the buffer
+    buffer.str("");
+
+    std::string urdfXml = R"(
+      <robot name='test_robot'>
+        <link name='link1'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <link name='link2'>
+          <inertial>
+            <mass value='0.1' />
+            <origin rpy='1.570796326794895 0 0' xyz='0.123456789123456 0 0.0' />
+            <inertia ixx='0.01' ixy='0' ixz='0' iyy='0.01' iyz='0' izz='0.01' />
+          </inertial>
+        </link>
+        <joint name='joint1_2' type='continuous'>
+          <parent link='link1' />
+          <child  link='link2' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+        <link name='link3'> <!-- zero mass link -->
+          <visual>
+            <origin rpy="3 -0 0" xyz="0 0 0"/>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </visual>
+          <collision>
+            <geometry>
+              <sphere radius="2.0"/>
+            </geometry>
+          </collision>
+        </link>
+        <joint name='joint2_3' type='fixed'>
+          <parent link='link2' />
+          <child  link='link3' />
+          <origin xyz='0.0 0.0 0.0' rpy='0.0 0.0 1.57'/>
+        </joint>
+      </robot>)";
+
+    sdf::Root root;
+    sdf::ParserConfig config;
+    config.URDFSetPreserveFixedJoint(true);
+    sdf::Errors errors = root.LoadSdfString(urdfXml, config);
+
+    // joint2_3 and link3 will be ignored, and warnings suggesting to remove
+    // gazebo tags
+    ASSERT_TRUE(errors.empty()) << errors;
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link3] has no <inertial> block defined. Please ensure this link "
+        "has a valid mass to prevent any missing links or joints in the "
+        "resulting SDF model");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "allowing joint lumping by removing any <disableFixedJointLumping> or "
+        "<preserveFixedJoint> gazebo tag on fixed parent joint[joint2_3], as "
+        "well as ensuring that ParserConfig::URDFPreserveFixedJoint is false, "
+        "could help resolve this warning");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "parent joint[joint2_3] ignored");
+    EXPECT_PRED2(sdf::testing::contains, buffer.str(),
+        "link[link3] is not modeled in sdf");
+
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("link1"));
 
@@ -687,8 +968,9 @@ TEST(URDF2SDF, URDFConvertForceTorqueSensorModels)
     const std::string sdfTestFile =
         sdf::testing::TestFile("integration", "force_torque_sensor.urdf");
     sdf::Root root;
-    sdf::Errors errors = root.Load(sdfTestFile);
-    EXPECT_TRUE(errors.empty());
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.Load(sdfTestFile, defaultConfig);
+    EXPECT_TRUE(errors.empty()) << errors;
   }
 
   // invalid force torque sensor, with massless child link, fixed parent joint,
@@ -706,10 +988,11 @@ TEST(URDF2SDF, URDFConvertForceTorqueSensorModels)
             "integration",
             "invalid_force_torque_sensor_lumped_and_reduced.urdf");
     sdf::Root root;
-    sdf::Errors errors = root.Load(sdfTestFile);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.Load(sdfTestFile, defaultConfig);
 
     // lumping and reduction occurs, we expect no warnings or errors
-    EXPECT_TRUE(errors.empty());
+    EXPECT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link_1] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -717,7 +1000,7 @@ TEST(URDF2SDF, URDFConvertForceTorqueSensorModels)
     EXPECT_PRED2(sdf::testing::notContains, buffer.str(),
         "link[link_1] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("base_link"));
     EXPECT_TRUE(model->FrameNameExists("link_1"));
@@ -737,10 +1020,11 @@ TEST(URDF2SDF, URDFConvertForceTorqueSensorModels)
             "integration",
             "invalid_force_torque_sensor_massless_child_link.urdf");
     sdf::Root root;
-    sdf::Errors errors = root.Load(sdfTestFile);
+    sdf::ParserConfig defaultConfig;
+    sdf::Errors errors = root.Load(sdfTestFile, defaultConfig);
 
     // lumping and reduction does not occur, joint_1 and link_1 ignored
-    EXPECT_TRUE(errors.empty());
+    EXPECT_TRUE(errors.empty()) << errors;
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link_1] has no <inertial> block defined. Please ensure this link "
         "has a valid mass to prevent any missing links or joints in the "
@@ -750,7 +1034,7 @@ TEST(URDF2SDF, URDFConvertForceTorqueSensorModels)
     EXPECT_PRED2(sdf::testing::contains, buffer.str(),
         "link[link_1] is not modeled in sdf");
 
-    const sdf::Model *model = root.ModelByIndex(0);
+    const sdf::Model *model = root.Model();
     ASSERT_NE(nullptr, model);
     EXPECT_TRUE(model->LinkNameExists("base_link"));
     EXPECT_TRUE(model->LinkNameExists("link_2"));
