@@ -80,7 +80,7 @@ TEST(DOMVisual, DoublePendulum)
   const sdf::Visual *plateVis = baseLink->VisualByIndex(0);
   ASSERT_TRUE(plateVis != nullptr);
 
-  EXPECT_EQ(ignition::math::Pose3d(0, 0, 0.01, 0, 0, 0), plateVis->RawPose());
+  EXPECT_EQ(gz::math::Pose3d(0, 0, 0.01, 0, 0, 0), plateVis->RawPose());
   EXPECT_EQ("", plateVis->PoseRelativeTo());
   EXPECT_FALSE(plateVis->CastShadows());
 
@@ -88,7 +88,7 @@ TEST(DOMVisual, DoublePendulum)
   ASSERT_TRUE(poleVis != nullptr);
   EXPECT_TRUE(poleVis->CastShadows());
 
-  EXPECT_EQ(ignition::math::Pose3d(-0.275, 0, 1.1, 0, 0, 0),
+  EXPECT_EQ(gz::math::Pose3d(-0.275, 0, 1.1, 0, 0, 0),
             poleVis->RawPose());
   EXPECT_EQ("", poleVis->PoseRelativeTo());
 }
@@ -115,10 +115,10 @@ TEST(DOMVisual, Material)
   const sdf::Material *mat = vis1->Material();
   ASSERT_NE(nullptr, mat);
 
-  EXPECT_EQ(ignition::math::Color(0.4f, 0.2f, 0.3f, 1.0f), mat->Ambient());
-  EXPECT_EQ(ignition::math::Color(0.2f, 0.5f, 0.1f, 1.0f), mat->Diffuse());
-  EXPECT_EQ(ignition::math::Color(0.7f, 0.3f, 0.5f, 0.9f), mat->Specular());
-  EXPECT_EQ(ignition::math::Color(1.0f, 0.0f, 0.2f, 1.0f), mat->Emissive());
+  EXPECT_EQ(gz::math::Color(0.4f, 0.2f, 0.3f, 1.0f), mat->Ambient());
+  EXPECT_EQ(gz::math::Color(0.2f, 0.5f, 0.1f, 1.0f), mat->Diffuse());
+  EXPECT_EQ(gz::math::Color(0.7f, 0.3f, 0.5f, 0.9f), mat->Specular());
+  EXPECT_EQ(gz::math::Color(1.0f, 0.0f, 0.2f, 1.0f), mat->Emissive());
   EXPECT_FALSE(mat->Lighting());
   EXPECT_TRUE(mat->DoubleSided());
   EXPECT_FLOAT_EQ(5.1f, mat->RenderOrder());
@@ -233,7 +233,7 @@ TEST(DOMVisual, LoadModelFramesRelativeToJoint)
   sdf::Root root;
   EXPECT_TRUE(root.Load(testFile).empty());
 
-  using Pose = ignition::math::Pose3d;
+  using Pose = gz::math::Pose3d;
 
   // Get the first model
   const sdf::Model *model = root.Model();
